import json
from datetime import datetime

import requests
from sqlalchemy import Engine, select
from sqlalchemy.orm import Session
from tqdm import tqdm

from nupes.cache import get_file
from nupes.models.geographie import BureauVote, Circonscription, Commune, Departement, Region


def importer_regions(engine: Engine, verbose: bool = False) -> None:
    etag = requests.get(
        "https://public.opendatasoft.com/api/explore/v2.1/catalog/datasets"
        "/georef-france-region?select=data_processed").json()['data_processed']
    file = get_file("https://public.opendatasoft.com/api/explore/v2.1/catalog/datasets"
                    "/georef-france-region/exports/geojson?lang=fr&timezone=Europe%2FParis",
                    "georef-france-region.geojson", etag)

    with file.open('r') as f:
        features = json.load(f)['features']

    with Session(engine) as session:
        for feature in tqdm(features, desc="Régions", disable=not verbose):
            region_dict = feature['properties']
            code_region = region_dict['reg_code'][0]
            nom_region = region_dict['reg_name'][0]

            if region := session.execute(select(Region).filter_by(code_insee=code_region)).scalar_one_or_none():
                region.libelle = nom_region
                region.geometry = feature['geometry']
            else:
                region = Region(code_insee=code_region, libelle=nom_region, geometry=feature['geometry'])
                session.add(region)

        if reg := session.execute(select(Region).filter_by(code_insee="ZZ")).scalar_one_or_none():
            reg.libelle = "Français⋅es de l'étranger"
        else:
            session.add(Region(code_insee="ZZ", libelle="Français⋅es de l'étranger", geometry={}))

        session.commit()


def importer_departements(engine: Engine, verbose: bool = False) -> None:
    etag = requests.get(
        "https://public.opendatasoft.com/api/explore/v2.1/catalog/datasets"
        "/georef-france-departement?select=data_processed").json()['data_processed']
    file = get_file("https://public.opendatasoft.com/api/explore/v2.1/catalog/datasets"
                    "/georef-france-departement/exports/geojson?lang=fr&timezone=Europe%2FParis",
                    "georef-france-departement.geojson", etag)

    with file.open('r') as f:
        features = json.load(f)['features']

    with Session(engine) as session:
        for feature in tqdm(features, desc="Départements", disable=not verbose):
            dpt_dict = feature['properties']
            code_dpt = dpt_dict['dep_code'][0]
            nom_dpt = dpt_dict['dep_name'][0]

            if dpt := session.execute(select(Departement).filter_by(code_insee=code_dpt)).scalar_one_or_none():
                dpt.libelle = nom_dpt
                dpt.region_code = dpt_dict['reg_code'][0]
                dpt.geometry = feature['geometry']
            else:
                dpt = Departement(code_insee=code_dpt, libelle=nom_dpt, region_code=dpt_dict['reg_code'][0],
                                  geometry=feature['geometry'])
                session.add(dpt)

        reg_etranger = session.execute(select(Region).filter_by(code_insee="ZZ")).scalar_one_or_none()
        if dpt := session.execute(select(Departement).filter_by(code_insee="ZZ")).scalar_one_or_none():
            dpt.libelle = "Français⋅es de l'étranger"
            dpt.region_code = reg_etranger.code_insee
        else:
            session.add(Departement(code_insee="ZZ", region_code=reg_etranger.code_insee,
                                    libelle="Français⋅es de l'étranger", geometry={}))

        session.commit()


def importer_circonscriptions(engine: Engine, verbose: bool = False) -> None:
    file = get_file("https://www.data.gouv.fr/fr/datasets/r/67c0f382-dc8d-4d1f-8a76-1162c53b9dfe",
                    "circonscriptions-legislatives-p10.geojson")

    with file.open('r') as f:
        features = json.load(f)['features']

    with Session(engine) as session:
        for feature in tqdm(features, desc="Circonscriptions", disable=not verbose):
            circo_dict = feature['properties']
            code_circo = circo_dict['codeCirconscription']
            code_dpt = circo_dict['codeDepartement']

            match code_dpt:
                case "ZA":
                    code_dpt = "971"
                case "ZB":
                    code_dpt = "972"
                case "ZC":
                    code_dpt = "973"
                case "ZD":
                    code_dpt = "974"
                case "ZS":
                    code_dpt = "975"
                case "ZM":
                    code_dpt = "976"

            numero_circo = int(code_circo[len(code_dpt):])
            circo_id = f"{code_dpt}-{numero_circo:02d}"

            if not session.execute(select(Departement).filter_by(code_insee=code_dpt)).scalar_one_or_none():
                print("Département non trouvé avec le code", code_dpt)
                continue

            if circo := session.execute(select(Circonscription).filter_by(id=circo_id)).scalar_one_or_none():
                circo.departement_code = code_dpt
                circo.numero = numero_circo
                circo.geometry = feature['geometry']
            else:
                circo = Circonscription(id=circo_id, departement_code=code_dpt, numero=numero_circo,
                                        geometry=feature['geometry'])
                session.add(circo)

        circos_manquantes = [
            {"id": "977-01", "dpt_id": "977", "numero": 1, "geometry": {"type": "MultiPolygon", "coordinates": [[[[-63.0962231, 18.0626091], [-63.0810858, 18.0775442], [-63.0733853, 18.0992942], [-63.0594206, 18.1002068], [-63.0261544, 18.1244364], [-63.0186821, 18.0864266], [-63.0400725, 18.0558043], [-63.0630925, 18.0637612], [-63.0779648, 18.0494371], [-63.0962231, 18.0626091]]], [[[-62.8741868, 17.921114], [-62.8487618, 17.9173852], [-62.8400082, 17.9045077], [-62.8089408, 17.916332], [-62.7955482, 17.8976021], [-62.836895, 17.8782328], [-62.8568851, 17.9084379], [-62.8741868, 17.921114]]]]}},
            {"id": "986-01", "dpt_id": "986", "numero": 1, "geometry": {"type": "MultiPolygon", "coordinates": [[[[-176.250845700000013, -13.2905881], [-176.2246769, -13.2779465], [-176.225896, -13.2524594], [-176.217776500000014, -13.2304078], [-176.1985703, -13.2188482], [-176.1623126, -13.2652837], [-176.183170499999989, -13.2977833], [-176.1993955, -13.3437724], [-176.2188721, -13.3480159], [-176.220019400000012, -13.3293755], [-176.2464393, -13.3138842], [-176.250845700000013, -13.2905881]]], [[[-178.0732659, -14.3461554], [-178.0674405, -14.3328053], [-178.0304501, -14.3235867], [-178.020343700000012, -14.3452517], [-178.041211, -14.3608773], [-178.0732659, -14.3461554]]], [[[-178.1817531, -14.2541568], [-178.178612, -14.2419722], [-178.131804499999987, -14.2592065], [-178.0879071, -14.2973257], [-178.0970111, -14.3085861], [-178.138506799999988, -14.3110959], [-178.168384, -14.2877385], [-178.1817531, -14.2541568]]]]}},
            {"id": "987-01", "dpt_id": "987", "numero": 1, "geometry": { "type": "MultiPolygon", "coordinates": [[[[-150.6519841, -17.664573], [-150.6280461, -17.6339506], [-150.609507400000012, -17.6579606], [-150.61044480000001, -17.671378], [-150.6290152, -17.6802192], [-150.6519841, -17.664573]]], [[[-140.7236136, -8.0183416], [-140.71225720000001, -7.984662], [-140.6478894, -7.9546087], [-140.6394687, -7.973936], [-140.6837973, -8.0014269], [-140.6946399, -8.0276016], [-140.693979500000012, -8.046678], [-140.718686600000012, -8.0419891], [-140.7236136, -8.0183416]]], [[[-140.5991139, -7.9301536], [-140.58308310000001, -7.9225675], [-140.5582193, -7.8983243], [-140.5514852, -7.9092729], [-140.581088, -7.9310629], [-140.5991139, -7.9301536]]], [[[-139.132470399999988, -9.9782264], [-139.1216646, -9.9556726], [-139.118212699999987, -9.9299696], [-139.09761, -9.8937184], [-139.0657965, -9.8925865], [-139.0354839, -9.9290056], [-139.039257600000013, -9.9476863], [-139.0778161, -9.9564439], [-139.1016903, -9.9824592], [-139.1090299, -10.0062867], [-139.1243585, -10.0123891], [-139.132470399999988, -9.9782264]]], [[[-139.163654, -9.7761829], [-139.149958, -9.7584125], [-139.1326685, -9.7501672], [-139.0921167, -9.7440426], [-139.0514784, -9.7204604], [-139.0057894, -9.6986602], [-138.9846197, -9.6978483], [-138.9686026, -9.7089725], [-138.9615633, -9.7386328], [-138.895173, -9.7374691], [-138.877850599999988, -9.7652924], [-138.8616372, -9.7588146], [-138.8466152, -9.7712134], [-138.8821929, -9.7993121], [-138.9120294, -9.8082275], [-138.9600164, -9.8075675], [-138.9738806, -9.8020459], [-138.9919047, -9.8125329], [-139.0407289, -9.8065608], [-139.0723288, -9.8504307], [-139.10159250000001, -9.8471271], [-139.133196, -9.8288693], [-139.163654, -9.7761829]]], [[[-140.1357659, -9.3804539], [-140.128599, -9.3828039], [-140.0995019, -9.3477965], [-140.074235499999986, -9.3374747], [-140.0237749, -9.3666652], [-140.036835200000013, -9.4482146], [-140.053206499999987, -9.4661609], [-140.076097299999986, -9.4614452], [-140.095427300000011, -9.4347038], [-140.1305946, -9.3994648], [-140.1357659, -9.3804539]]], [[[-138.8421208, -9.9761737], [-138.825354800000014, -9.9739804], [-138.812691199999989, -9.9965577], [-138.8271196, -10.0061471], [-138.8421208, -9.9761737]]], [[[-138.6922348, -10.520104], [-138.676520399999987, -10.4951894], [-138.6729919, -10.4521527], [-138.6891464, -10.425858], [-138.656529, -10.42167], [-138.6132548, -10.4599586], [-138.6129132, -10.5035526], [-138.6363565, -10.5412218], [-138.66452670000001, -10.5408913], [-138.6922348, -10.520104]]], [[[-139.614458, -8.9220143], [-139.6034282, -8.8940112], [-139.5505729, -8.8653155], [-139.5085587, -8.8817651], [-139.486114, -8.9214481], [-139.5431484, -8.9313261], [-139.5912108, -8.9505286], [-139.614458, -8.9220143]]], [[[-140.2519428, -8.8247989], [-140.247368200000011, -8.7999327], [-140.2006218, -8.7821794], [-140.1568292, -8.7927946], [-140.125704, -8.8162535], [-140.106980600000014, -8.8096688], [-140.092098099999987, -8.8169331], [-140.0729318, -8.8032571], [-140.066427, -8.8254414], [-140.0538114, -8.8272718], [-140.036185499999988, -8.7997735], [-140.014711299999988, -8.8065925], [-140.046659299999988, -8.827925], [-140.0336077, -8.8460475], [-140.012434500000012, -8.8472179], [-140.0159272, -8.874392], [-140.00946110000001, -8.9033851], [-140.0288899, -8.9007037], [-140.0368492, -8.8849592], [-140.0532033, -8.8957564], [-140.0426843, -8.9129162], [-140.0823157, -8.925017], [-140.1047249, -8.9121983], [-140.108773, -8.9342903], [-140.132307200000014, -8.9431044], [-140.1699045, -8.9428567], [-140.1894847, -8.9601218], [-140.197847599999989, -8.9465403], [-140.225009300000011, -8.929522], [-140.2293546, -8.8821535], [-140.2485179, -8.8466101], [-140.2519428, -8.8247989]]], [[[-145.213262899999989, -19.8669427], [-145.2080728, -19.8234612], [-145.195310400000011, -19.7865424], [-145.1710969, -19.7467797], [-145.1542288, -19.727656], [-145.099858500000011, -19.6772658], [-145.0698708, -19.6584942], [-145.008476300000012, -19.6375906], [-144.9642409, -19.6339962], [-144.914219300000013, -19.6392031], [-144.8800244, -19.6485867], [-144.834409599999987, -19.670203], [-144.792044800000014, -19.7030909], [-144.7665552, -19.7337536], [-144.7518014, -19.7595989], [-144.736414200000013, -19.8047629], [-144.7247796, -19.8648243], [-144.7241043, -19.9242767], [-144.735847799999988, -19.9721149], [-144.7661309, -20.0272983], [-144.801053200000013, -20.0638523], [-144.839307600000012, -20.088857], [-144.896069399999988, -20.1090098], [-144.960635200000013, -20.115006], [-144.995826, -20.110383], [-145.0504496, -20.0903603], [-145.083900699999987, -20.0687103], [-145.1632406, -20.0000654], [-145.197530300000011, -19.9457417], [-145.209113699999989, -19.9081121], [-145.213262899999989, -19.8669427]]], [[[-140.6450017, -19.6337924], [-140.6313978, -19.564006], [-140.5994263, -19.5041892], [-140.573676799999987, -19.4736822], [-140.5290561, -19.4386727], [-140.492537199999987, -19.4211851], [-140.4581995, -19.4118247], [-140.4176037, -19.4082911], [-140.371544300000011, -19.412438], [-140.337598899999989, -19.4213718], [-140.2891512, -19.4454322], [-140.2629124, -19.4650418], [-140.225440600000013, -19.5018659], [-140.201758399999989, -19.5345418], [-140.180867, -19.5812375], [-140.173641800000013, -19.6144407], [-140.1720606, -19.6528408], [-140.1781259, -19.6908221], [-140.1896194, -19.7237745], [-140.2226283, -19.7776901], [-140.2534612, -19.8089307], [-140.2943579, -19.8362109], [-140.3489289, -19.8560848], [-140.4054166, -19.8627546], [-140.4545339, -19.8579292], [-140.5083581, -19.840105], [-140.560386200000011, -19.8082444], [-140.5913258, -19.7785829], [-140.625703499999986, -19.7242644], [-140.641669, -19.672803], [-140.6450017, -19.6337924]]], [[[-139.4674603, -19.3556719], [-139.4595698, -19.2987462], [-139.441899299999989, -19.2568735], [-139.4155948, -19.220442], [-139.3936904, -19.1996773], [-139.349148500000013, -19.1696277], [-139.3095997, -19.149493], [-139.2467088, -19.1299403], [-139.1983204, -19.1276103], [-139.154050399999988, -19.1349902], [-139.12376660000001, -19.1451732], [-139.0853837, -19.1652515], [-139.0585711, -19.1860789], [-139.028742200000011, -19.2184991], [-139.0053546, -19.2153878], [-138.988138, -19.1785284], [-138.9700844, -19.1528215], [-138.9421462, -19.1249654], [-138.8990618, -19.0972983], [-138.8371464, -19.0778246], [-138.7748943, -19.0727489], [-138.729627599999986, -19.0758655], [-138.6920753, -19.0858321], [-138.6597835, -19.1004958], [-138.6166987, -19.1319742], [-138.5962998, -19.1543683], [-138.574895700000013, -19.1883097], [-138.5634061, -19.2168681], [-138.51175090000001, -19.2597195], [-138.480887599999988, -19.3060692], [-138.4716378, -19.3281183], [-138.459675299999986, -19.3858905], [-138.4605732, -19.4248394], [-138.4663878, -19.4535343], [-138.4839825, -19.49634], [-138.4974463, -19.5175194], [-138.53198470000001, -19.5542373], [-138.5641116, -19.5764083], [-138.596612, -19.5914532], [-138.6403989, -19.602606], [-138.7039921, -19.603218], [-138.7529946, -19.5912127], [-138.7892008, -19.5736457], [-138.8303417, -19.5419211], [-138.859377099999989, -19.5060978], [-138.8764801, -19.4735564], [-138.935413, -19.4423909], [-138.9717044, -19.4079488], [-138.991005699999988, -19.3798657], [-139.0019202, -19.4167669], [-139.0201195, -19.4566734], [-139.0537281, -19.5015216], [-139.0927393, -19.5329008], [-139.1350309, -19.5545541], [-139.1801557, -19.5668572], [-139.221338300000014, -19.5695233], [-139.295517499999988, -19.5574587], [-139.330707499999988, -19.5452447], [-139.3805237, -19.5178878], [-139.40591, -19.496687], [-139.4344491, -19.4626008], [-139.4509022, -19.4324037], [-139.4632, -19.3938136], [-139.4674603, -19.3556719]]], [[[-138.785408100000012, -20.8244077], [-138.7797112, -20.7707841], [-138.765369600000014, -20.7111663], [-138.7365878, -20.6546584], [-138.698954, -20.6156081], [-138.6441039, -20.5838008], [-138.6042836, -20.5725045], [-138.567649, -20.568874], [-138.509525, -20.5757332], [-138.4635568, -20.5921167], [-138.3799907, -20.6439846], [-138.353772600000013, -20.6675115], [-138.3280829, -20.7004633], [-138.3032385, -20.7588279], [-138.295366, -20.7971228], [-138.2953252, -20.8483719], [-138.3053175, -20.9180998], [-138.318694, -20.9598331], [-138.351829900000013, -21.0124664], [-138.377369499999986, -21.0374118], [-138.4176076, -21.063828], [-138.4506929, -21.0773291], [-138.499304599999988, -21.0871161], [-138.5288348, -21.0879373], [-138.5871448, -21.077599], [-138.627317, -21.0612444], [-138.690968, -21.018124], [-138.731673300000011, -20.9803741], [-138.7673479, -20.9245486], [-138.7798668, -20.8827548], [-138.785408100000012, -20.8244077]]], [[[-139.35955580000001, -20.7802757], [-139.3559267, -20.7410342], [-139.334594399999986, -20.6819801], [-139.311268399999989, -20.6470742], [-139.265372500000012, -20.6052856], [-139.227273200000013, -20.5848397], [-139.188921, -20.5729093], [-139.14152390000001, -20.5678373], [-139.0988695, -20.5713501], [-139.04193570000001, -20.5895078], [-139.0047964, -20.6119818], [-138.974097199999989, -20.6397573], [-138.9388725, -20.6940285], [-138.9248034, -20.7377474], [-138.9210161, -20.7774432], [-138.9258453, -20.8202124], [-138.9484386, -20.8818578], [-138.9876051, -20.9338725], [-139.0197671, -20.9594931], [-139.0807105, -20.9878597], [-139.132046699999989, -20.9966164], [-139.174233, -20.994703], [-139.234928, -20.9765006], [-139.2792374, -20.9489836], [-139.3035927, -20.9261041], [-139.329879299999988, -20.8904445], [-139.3460145, -20.8567774], [-139.3566892, -20.8163005], [-139.35955580000001, -20.7802757]]], [[[-142.0770408, -18.72259], [-142.0733352, -18.6788652], [-142.060743, -18.6366509], [-142.044465300000013, -18.6058258], [-142.0071465, -18.5621955], [-141.9595373, -18.5296359], [-141.9176558, -18.5135781], [-141.8566183, -18.5051566], [-141.765943, -18.5161457], [-141.7115249, -18.5341793], [-141.676939, -18.5529873], [-141.6172556, -18.6019231], [-141.5861946, -18.6354247], [-141.55746, -18.6875683], [-141.5471858, -18.7259229], [-141.5449548, -18.7654821], [-141.555126300000012, -18.8189819], [-141.583249200000012, -18.8825255], [-141.6024574, -18.9114112], [-141.6266383, -18.9377829], [-141.6654509, -18.9673083], [-141.706881399999986, -18.9888501], [-141.776537100000013, -19.0070386], [-141.8323738, -19.0076725], [-141.8886128, -18.9938003], [-141.931955499999987, -18.971262], [-141.9624158, -18.9466357], [-141.9996552, -18.9017803], [-142.0532476, -18.8235808], [-142.0685657, -18.7830905], [-142.0770408, -18.72259]]], [[[-140.928552700000012, -19.1249238], [-140.9258434, -19.0913775], [-140.9116788, -19.0433398], [-140.8768091, -18.9880571], [-140.826930800000014, -18.9462169], [-140.7884204, -18.9280838], [-140.7594279, -18.919893], [-140.7162796, -18.9152269], [-140.6771162, -18.9175013], [-140.622198, -18.9272268], [-140.5867781, -18.9378772], [-140.5441116, -18.9604155], [-140.5199533, -18.9793828], [-140.4905331, -19.0119199], [-140.4746242, -19.0377554], [-140.457622, -19.0815489], [-140.4514566, -19.1188353], [-140.4542583, -19.1709932], [-140.47474170000001, -19.230209], [-140.5028137, -19.2729671], [-140.5514618, -19.316749], [-140.595404300000013, -19.3409224], [-140.6538381, -19.3561185], [-140.7088357, -19.3564749], [-140.7532641, -19.3471673], [-140.7960433, -19.3296141], [-140.8352615, -19.3044789], [-140.863586700000013, -19.279681], [-140.8941582, -19.2413873], [-140.914587899999987, -19.2014637], [-140.9257781, -19.1598129], [-140.928552700000012, -19.1249238]]], [[[-141.469346, -19.1893907], [-141.464473700000013, -19.1468197], [-141.444891899999988, -19.0921834], [-141.4289645, -19.0663543], [-141.384022, -19.0214345], [-141.3453862, -18.9986665], [-141.3074512, -18.9856809], [-141.2736133, -18.9798259], [-141.2340098, -18.9797193], [-141.189221, -18.9882141], [-141.1460822, -19.005685], [-141.1112973, -19.0284721], [-141.085317300000014, -19.0521574], [-141.050598900000011, -19.0965824], [-141.0304663, -19.1381583], [-141.0187096, -19.1891509], [-141.017904, -19.2223708], [-141.0305151, -19.2836693], [-141.0491221, -19.3214346], [-141.0739098, -19.3531068], [-141.1216489, -19.3911967], [-141.161573, -19.4102597], [-141.190485200000012, -19.4185534], [-141.235638200000011, -19.4237375], [-141.279999, -19.4201777], [-141.32257580000001, -19.4083074], [-141.352614499999987, -19.3938427], [-141.3866514, -19.3699838], [-141.4142531, -19.3416474], [-141.434652, -19.3122845], [-141.4588582, -19.2582538], [-141.4673824, -19.2210878], [-141.469346, -19.1893907]]], [[[-136.6744728, -18.470822], [-136.67211180000001, -18.4412158], [-136.6611426, -18.3985564], [-136.632788799999986, -18.3474856], [-136.6095831, -18.3220756], [-136.559628, -18.2869854], [-136.5108339, -18.2687116], [-136.4462802, -18.2618045], [-136.406181800000013, -18.2657974], [-136.3721367, -18.2746806], [-136.263412100000011, -18.3272201], [-136.1816272, -18.3852658], [-136.131144299999988, -18.4346801], [-136.113904600000012, -18.4594303], [-136.0945882, -18.5006187], [-136.0839919, -18.5499256], [-136.08398170000001, -18.5902875], [-136.0980462, -18.6471871], [-136.1113086, -18.6738359], [-136.1373528, -18.7090772], [-136.1623783, -18.7324701], [-136.1911146, -18.7514724], [-136.250147700000014, -18.7740514], [-136.3051611, -18.7803453], [-136.3760135, -18.7721504], [-136.418217700000014, -18.7583288], [-136.4608883, -18.7353307], [-136.4976443, -18.7055013], [-136.5279488, -18.6745863], [-136.5637317, -18.6571411], [-136.6105087, -18.6207362], [-136.6438082, -18.5788495], [-136.6570356, -18.5532365], [-136.6714503, -18.5053298], [-136.6744728, -18.470822]]], [[[-139.427599, -18.5571741], [-139.416388899999987, -18.4925799], [-139.3994068, -18.4565526], [-139.3820126, -18.4320487], [-139.3493656, -18.4006301], [-139.301900499999988, -18.372307], [-139.2576128, -18.3582614], [-139.2057634, -18.35369], [-139.1738584, -18.3567161], [-139.1250804, -18.3704411], [-139.087321300000013, -18.3902045], [-139.0510711, -18.4200592], [-139.0189661, -18.4635722], [-139.001530300000013, -18.5062199], [-138.9945483, -18.5497931], [-138.9981706, -18.6280027], [-138.9579941, -18.5996695], [-138.8939449, -18.5732503], [-138.8520605, -18.5644676], [-138.8011731, -18.5609879], [-138.738475, -18.5695696], [-138.689186799999987, -18.5892074], [-138.6445574, -18.6206046], [-138.6181023, -18.649483], [-138.6005151, -18.6767567], [-138.582689499999987, -18.7233263], [-138.5775834, -18.7577765], [-138.579069, -18.79953], [-138.5923295, -18.8484107], [-138.6106849, -18.8829697], [-138.655254, -18.9322272], [-138.683767499999988, -18.9518077], [-138.7285249, -18.9721136], [-138.7754668, -18.9834187], [-138.842441900000011, -18.9883881], [-138.8828762, -18.9858863], [-138.9507525, -18.964481], [-138.9928208, -18.9380988], [-139.0143668, -18.9181957], [-139.0395738, -18.8852228], [-139.0551273, -18.8546701], [-139.06508, -18.8220089], [-139.0692005, -18.7784507], [-139.0588324, -18.7187819], [-139.0789307, -18.7200341], [-139.1040355, -18.7354324], [-139.142724, -18.7513801], [-139.200369, -18.7616535], [-139.2588776, -18.7573437], [-139.316324400000013, -18.7372198], [-139.3539294, -18.7123711], [-139.3787322, -18.6878842], [-139.40690140000001, -18.64583], [-139.4262866, -18.5812538], [-139.427599, -18.5571741]]], [[[-137.279984, -18.2641324], [-137.2728196, -18.2110186], [-137.2459422, -18.1533691], [-137.216955399999989, -18.1195989], [-137.1632841, -18.0834073], [-137.120145400000013, -18.0676003], [-137.0554152, -18.0614648], [-137.0086806, -18.0684479], [-136.9505728, -18.0928135], [-136.8948064, -18.1300325], [-136.8467914, -18.1737479], [-136.8082451, -18.215657], [-136.778977200000014, -18.2597018], [-136.760482700000011, -18.3074853], [-136.754100200000011, -18.3537534], [-136.7568229, -18.3923972], [-136.7639175, -18.4206476], [-136.789013, -18.4710022], [-136.810882099999986, -18.4979716], [-136.8481698, -18.5292314], [-136.87438130000001, -18.5440279], [-136.9122767, -18.5576955], [-136.9676385, -18.5646717], [-137.0149465, -18.5606158], [-137.0753779, -18.5414098], [-137.1297357, -18.5127307], [-137.1801726, -18.4730295], [-137.2106767, -18.43591], [-137.2589696, -18.3547484], [-137.268080200000014, -18.3326745], [-137.279984, -18.2641324]]], [[[-143.2987281, -17.8650704], [-143.2901818, -17.7970098], [-143.2742002, -17.7569631], [-143.236232300000012, -17.7043611], [-143.1918104, -17.6688336], [-143.1543764, -17.6498606], [-143.10038, -17.6354638], [-143.0559491, -17.6337924], [-143.0243749, -17.6381073], [-142.98119, -17.652183], [-142.9504346, -17.6692654], [-142.911815600000011, -17.7025847], [-142.8775238, -17.7548305], [-142.862909300000013, -17.7981299], [-142.8536705, -17.8490232], [-142.852450800000014, -17.887635], [-142.858952499999987, -17.925751], [-142.870791, -17.9575724], [-142.8984573, -18.0010001], [-142.9284946, -18.0305721], [-142.9742941, -18.0590229], [-143.0051823, -18.0710152], [-143.056595499999986, -18.0803215], [-143.1035842, -18.0784664], [-143.144898899999987, -18.0688103], [-143.20031130000001, -18.0409288], [-143.251186, -17.9931981], [-143.2761499, -17.9534476], [-143.2878351, -17.9256814], [-143.2987281, -17.8650704]]], [[[-149.5813852, -17.5448667], [-149.5671692, -17.5262661], [-149.543051100000014, -17.520921], [-149.5125276, -17.5223993], [-149.5036173, -17.5117024], [-149.4895291, -17.552328], [-149.4945684, -17.6126505], [-149.512820299999987, -17.6234262], [-149.521774599999986, -17.5971371], [-149.5825792, -17.5563973], [-149.5813852, -17.5448667]]], [[[-149.9159252, -17.5027033], [-149.9079032, -17.490419], [-149.8707444, -17.4918779], [-149.854004, -17.4996762], [-149.8449293, -17.4846681], [-149.816768700000011, -17.4845358], [-149.7750992, -17.4733101], [-149.7636483, -17.4997456], [-149.7768213, -17.5239572], [-149.7985515, -17.5813752], [-149.8084524, -17.5921175], [-149.837479800000011, -17.5920623], [-149.8519805, -17.5843904], [-149.8737663, -17.5569268], [-149.9035476, -17.5367854], [-149.9159252, -17.5027033]]], [[[-142.6048854, -18.0455691], [-142.6002145, -18.0022893], [-142.588252899999986, -17.956912], [-142.5685077, -17.9128706], [-142.5328352, -17.8685715], [-142.486522400000013, -17.8352286], [-142.4449356, -17.8180904], [-142.4156147, -17.8111773], [-142.3595818, -17.8075615], [-142.3269996, -17.7871544], [-142.26381, -17.7620148], [-142.19984, -17.7543648], [-142.1458332, -17.761603], [-142.10830150000001, -17.7749129], [-142.074125, -17.7949538], [-142.027295400000014, -17.8413725], [-142.000260200000014, -17.8931761], [-141.9886845, -17.9380988], [-141.9868242, -17.969772], [-141.9775661, -18.0116141], [-141.9811023, -18.0767951], [-141.9590791, -18.1165609], [-141.934485, -18.1492129], [-141.9188073, -18.1800699], [-141.9047994, -18.2276809], [-141.9007815, -18.2629434], [-141.9026706, -18.2965912], [-141.9163838, -18.3459808], [-141.953414400000014, -18.4042538], [-141.979609399999987, -18.4293331], [-142.0187201, -18.4541433], [-142.0487034, -18.4805146], [-142.0951607, -18.5061915], [-142.1430805, -18.5194999], [-142.172932, -18.5220002], [-142.2225082, -18.5168583], [-142.25891390000001, -18.5054972], [-142.3036576, -18.480323], [-142.338391300000012, -18.4480321], [-142.3617056, -18.4153451], [-142.3814907, -18.3698046], [-142.3931428, -18.3019213], [-142.422424299999989, -18.2806137], [-142.4541659, -18.2683675], [-142.508991400000014, -18.2304133], [-142.5545995, -18.1790606], [-142.5872862, -18.1289053], [-142.6018598, -18.0815076], [-142.6048854, -18.0455691]]], [[[-141.7375649, -17.3770698], [-141.728401, -17.3136708], [-141.7074096, -17.2687022], [-141.6812788, -17.2346498], [-141.639783200000011, -17.1993778], [-141.6082444, -17.1821838], [-141.570027399999987, -17.168441], [-141.5250045, -17.1604221], [-141.4681363, -17.1628689], [-141.4345141, -17.1707847], [-141.3877137, -17.1921913], [-141.350607, -17.2195743], [-141.330071800000013, -17.241162], [-141.305642400000011, -17.2783831], [-141.2826833, -17.3342009], [-141.2760146, -17.3722832], [-141.276508, -17.4060877], [-141.2852484, -17.4476771], [-141.3057461, -17.4924575], [-141.3431731, -17.5372741], [-141.367158, -17.5561969], [-141.4110629, -17.580086], [-141.4460899, -17.5916404], [-141.497165599999988, -17.6003955], [-141.5322579, -17.5999447], [-141.5990842, -17.5830467], [-141.642769, -17.5576886], [-141.6789507, -17.5233], [-141.6994459, -17.4942936], [-141.722109499999988, -17.4497867], [-141.7346044, -17.4065771], [-141.7375649, -17.3770698]]], [[[-141.2792947, -18.1166771], [-141.27193840000001, -18.0494179], [-141.25700040000001, -18.0054515], [-141.2309214, -17.9590558], [-141.1973674, -17.9228254], [-141.1426573, -17.8887818], [-141.0812469, -17.8717472], [-141.069215, -17.8247172], [-141.047835099999986, -17.7672667], [-141.0308043, -17.7377713], [-140.9651606, -17.649438], [-140.923547, -17.6143189], [-140.8684187, -17.584405], [-140.826365, -17.5516387], [-140.7787046, -17.5239605], [-140.7500791, -17.5142349], [-140.695875, -17.5060085], [-140.6478378, -17.5079752], [-140.6095843, -17.5155801], [-140.5619177, -17.5346581], [-140.529502400000013, -17.5538751], [-140.4995739, -17.5794004], [-140.478082300000011, -17.6044453], [-140.457015, -17.6400162], [-140.4400718, -17.6974454], [-140.4391807, -17.7438353], [-140.4451391, -17.7805603], [-140.4707574, -17.8456795], [-140.5042085, -17.8986912], [-140.5411298, -17.9398208], [-140.5794166, -17.9671915], [-140.6406863, -18.0334714], [-140.674421700000011, -18.056576], [-140.6509246, -18.0848433], [-140.6247761, -18.1292972], [-140.610049299999986, -18.1761301], [-140.6065438, -18.2064081], [-140.545272, -18.2490506], [-140.510041699999988, -18.2851281], [-140.4758235, -18.3395949], [-140.4626508, -18.3733746], [-140.455158399999988, -18.4222947], [-140.4595238, -18.4694845], [-140.4713179, -18.5067263], [-140.4876162, -18.5369633], [-140.5159639, -18.5711429], [-140.542957199999989, -18.5931039], [-140.5853377, -18.6159567], [-140.624172, -18.6273568], [-140.6757542, -18.6311459], [-140.738462199999987, -18.6259785], [-140.7917716, -18.6178321], [-140.8669108, -18.5959455], [-140.941947699999986, -18.5607539], [-140.976962, -18.5316566], [-141.0684143, -18.4315798], [-141.089578499999988, -18.3982324], [-141.124174399999987, -18.3710957], [-141.148080599999986, -18.3461064], [-141.1818897, -18.3236637], [-141.2102444, -18.2954501], [-141.2274439, -18.2710589], [-141.260446800000011, -18.2107852], [-141.2771533, -18.1500655], [-141.2792947, -18.1166771]]], [[[-138.663746800000013, -17.3466565], [-138.659988700000014, -17.3132643], [-138.6431753, -17.2628005], [-138.6191653, -17.2249317], [-138.6001492, -17.2037777], [-138.562005699999986, -17.1739534], [-138.5194473, -17.1513677], [-138.4886285, -17.1404254], [-138.4411455, -17.1298943], [-138.3353775, -17.1258418], [-138.291132299999987, -17.1305738], [-138.233458500000012, -17.1510325], [-138.197016499999989, -17.1746477], [-138.1595592, -17.2132712], [-138.133924400000012, -17.2600441], [-138.1230469, -17.2996902], [-138.120374, -17.3331682], [-138.1235476, -17.3666057], [-138.139332700000011, -17.4165255], [-138.1715135, -17.4656342], [-138.2048049, -17.4967713], [-138.2685525, -17.5356259], [-138.3097808, -17.5498113], [-138.3428307, -17.5562822], [-138.431340299999988, -17.5599483], [-138.4769346, -17.5569187], [-138.5344981, -17.5420083], [-138.5730662, -17.5214581], [-138.6098965, -17.4897564], [-138.631515, -17.4624438], [-138.6516383, -17.4227832], [-138.660741800000011, -17.3895461], [-138.663746800000013, -17.3466565]]], [[[-142.880321900000013, -17.5530933], [-142.868899699999986, -17.4826177], [-142.8575615, -17.4558005], [-142.8364329, -17.4230409], [-142.8102749, -17.3952124], [-142.784064199999989, -17.3752871], [-142.794568199999986, -17.3383388], [-142.7961118, -17.2802361], [-142.784074, -17.2331632], [-142.7577207, -17.1863246], [-142.7329091, -17.1587076], [-142.6814941, -17.1233028], [-142.6320144, -17.1057519], [-142.597911399999987, -17.1009093], [-142.5549896, -17.1022721], [-142.5223751, -17.1084297], [-142.4760267, -17.1247801], [-142.4255278, -17.1565225], [-142.3921212, -17.1907933], [-142.3588693, -17.2505542], [-142.34753090000001, -17.302184], [-142.3484143, -17.34198], [-142.3549387, -17.3734742], [-142.3692877, -17.4095688], [-142.4006353, -17.4548713], [-142.3690066, -17.492776], [-142.3527393, -17.5238066], [-142.337153199999989, -17.588775], [-142.3384514, -17.6349145], [-142.3442872, -17.6634074], [-142.3585961, -17.6995555], [-142.3840773, -17.7383315], [-142.4336499, -17.7849861], [-142.468683199999987, -17.8062843], [-142.5127118, -17.8243009], [-142.556378599999988, -17.8338151], [-142.628064, -17.8348876], [-142.6889897, -17.8217065], [-142.7177699, -17.8118266], [-142.7631557, -17.7868367], [-142.7951095, -17.7623071], [-142.8330999, -17.7203851], [-142.8586747, -17.6751035], [-142.873173799999989, -17.6339412], [-142.880321900000013, -17.5530933]]], [[[-143.689363500000013, -17.4456826], [-143.6831176, -17.4002405], [-143.667153, -17.3580084], [-143.6384665, -17.3164729], [-143.6226404, -17.3004908], [-143.5734546, -17.2671166], [-143.5360081, -17.253122], [-143.4864282, -17.2458708], [-143.4090977, -17.2498924], [-143.3659571, -17.2622198], [-143.3278532, -17.2787023], [-143.296965199999988, -17.2977148], [-143.2483303, -17.3452524], [-143.219176800000014, -17.4001254], [-143.2080712, -17.455376], [-143.213987300000014, -17.5170037], [-143.229227900000012, -17.5576976], [-143.2614149, -17.6046246], [-143.3119251, -17.6460256], [-143.3652432, -17.6727117], [-143.4008526, -17.6845785], [-143.4437737, -17.6903366], [-143.4789089, -17.6890568], [-143.5312232, -17.6768228], [-143.572266899999988, -17.6566942], [-143.6057331, -17.6317557], [-143.636629, -17.5977679], [-143.65619670000001, -17.5648976], [-143.6779821, -17.5155221], [-143.6877381, -17.4746222], [-143.689363500000013, -17.4456826]]], [[[-145.8161417, -17.3507419], [-145.81376370000001, -17.31927], [-145.800249799999989, -17.2715196], [-145.764337399999988, -17.2119229], [-145.736520399999989, -17.1819524], [-145.713271099999986, -17.1641219], [-145.666215200000011, -17.1394971], [-145.608807899999988, -17.1246542], [-145.5374929, -17.1267555], [-145.4642829, -17.1434964], [-145.4159582, -17.1621528], [-145.3666144, -17.1985132], [-145.3292394, -17.2501108], [-145.2902096, -17.277807], [-145.233949, -17.3433598], [-145.2078769, -17.3827054], [-145.188656, -17.4276895], [-145.1813994, -17.4650404], [-145.181930099999988, -17.513792], [-145.191324, -17.5530232], [-145.2098902, -17.5924748], [-145.2411524, -17.6319092], [-145.2685961, -17.6544767], [-145.3266413, -17.6848106], [-145.360475400000013, -17.6951728], [-145.395646, -17.6997904], [-145.4577185, -17.6971571], [-145.526418299999989, -17.6809399], [-145.5677667, -17.6630214], [-145.6043596, -17.6373589], [-145.648639300000013, -17.5847727], [-145.709562, -17.5538406], [-145.7449897, -17.5213757], [-145.7724107, -17.4839712], [-145.7943655, -17.4439571], [-145.8129059, -17.3867754], [-145.8161417, -17.3507419]]], [[[-142.1412887, -16.8294913], [-142.1399235, -16.8053883], [-142.128251799999987, -16.7585358], [-142.1149637, -16.7307252], [-142.085466200000013, -16.6912217], [-142.0301595, -16.6498213], [-141.9708326, -16.628591], [-141.9198246, -16.6235053], [-141.887912300000011, -16.626268], [-141.8425203, -16.6386725], [-141.806462, -16.6569697], [-141.7799512, -16.6768902], [-141.7522927, -16.7058791], [-141.7202847, -16.7571165], [-141.708954299999988, -16.7869197], [-141.700543, -16.8371069], [-141.7029858, -16.8766513], [-141.713464, -16.9149513], [-141.7263591, -16.9419488], [-141.7565759, -16.9818941], [-141.796275900000012, -17.014013], [-141.858895, -17.0403781], [-141.89831190000001, -17.0466851], [-141.943202899999989, -17.0448825], [-142.008332200000012, -17.0270146], [-142.0377356, -17.0125263], [-142.070179200000013, -16.9887905], [-142.0989994, -16.9573931], [-142.1194126, -16.9234312], [-142.136763300000013, -16.8718125], [-142.1412887, -16.8294913]]], [[[-148.9237939, -14.8775793], [-148.921253799999988, -14.8446212], [-148.9084324, -14.7979981], [-148.893302299999988, -14.7670442], [-148.8679319, -14.7324238], [-148.8315116, -14.6991402], [-148.7988461, -14.6790457], [-148.766563600000012, -14.665853], [-148.701589500000011, -14.6557485], [-148.629909199999986, -14.6636835], [-148.564208, -14.682434], [-148.514560100000011, -14.7075048], [-148.466879299999988, -14.7502187], [-148.4453435, -14.7818561], [-148.4240427, -14.8350759], [-148.4014196, -14.8105987], [-148.3186159, -14.7461038], [-148.264906200000013, -14.7202288], [-148.189989, -14.7050861], [-148.124152, -14.7048242], [-148.0785467, -14.7138619], [-148.03387570000001, -14.7294417], [-147.9743334, -14.7571593], [-147.926286800000014, -14.7309467], [-147.891981, -14.7209103], [-147.844845, -14.716155], [-147.7841133, -14.7205366], [-147.735400199999987, -14.7312374], [-147.6499996, -14.7440993], [-147.5585889, -14.774815], [-147.5188121, -14.7954012], [-147.4677407, -14.8308849], [-147.4334199, -14.8609116], [-147.407418, -14.8950378], [-147.372255599999988, -14.9309893], [-147.336771700000014, -14.9519338], [-147.2943302, -14.9860843], [-147.2605644, -15.020856], [-147.2207515, -15.0245269], [-147.175823400000013, -15.0343034], [-147.1235048, -15.0599617], [-147.08901130000001, -15.0889536], [-147.064554500000014, -15.1203302], [-147.0484818, -15.1511699], [-147.021764100000013, -15.1231286], [-146.9931578, -15.1022504], [-146.957619599999987, -15.0568799], [-146.9233075, -15.0298224], [-146.8828977, -15.0095079], [-146.8186829, -14.9962919], [-146.758482, -15.0015456], [-146.6355096, -15.0334901], [-146.574632, -15.0452085], [-146.500767599999989, -15.079288], [-146.4611539, -15.1105749], [-146.4228579, -15.101514], [-146.3589663, -15.099597], [-146.315635, -15.1088668], [-146.256539299999986, -15.1135767], [-146.2207546, -15.1247207], [-146.145848699999988, -15.1386847], [-146.1045957, -15.1522264], [-146.071836, -15.1700829], [-146.0446144, -15.1912922], [-146.0214848, -15.2166313], [-145.9975365, -15.2562927], [-145.987207399999988, -15.2842737], [-145.9798662, -15.330533], [-145.9818706, -15.369844], [-145.991561100000013, -15.4268114], [-146.0153795, -15.4937006], [-146.0158367, -15.5292861], [-146.0297716, -15.5989181], [-145.966678300000012, -15.6097974], [-145.9320246, -15.6224087], [-145.8424518, -15.6736174], [-145.782180399999987, -15.7150186], [-145.7601803, -15.7351932], [-145.72603380000001, -15.7806774], [-145.7029599, -15.8265695], [-145.6845159, -15.851808], [-145.6396498, -15.8474916], [-145.598268100000013, -15.8497572], [-145.5492749, -15.8615721], [-145.520981, -15.8742583], [-145.4803421, -15.9024321], [-145.4576693, -15.925719], [-145.4675489, -15.8632397], [-145.466004199999986, -15.8254194], [-145.5017159, -15.8288626], [-145.5569892, -15.8238902], [-145.5817477, -15.8168188], [-145.62409310000001, -15.7970734], [-145.6671594, -15.7703298], [-145.6940505, -15.7470382], [-145.7390239, -15.7000543], [-145.7720242, -15.6490028], [-145.7845687, -15.6115641], [-145.7978606, -15.5286117], [-145.7949197, -15.4727185], [-145.7866019, -15.4399792], [-145.7548184, -15.3715857], [-145.7294478, -15.3361443], [-145.6895213, -15.2993069], [-145.6358511, -15.2698698], [-145.567932399999989, -15.2557292], [-145.518755199999987, -15.2583185], [-145.4820058, -15.2676928], [-145.4449994, -15.2836178], [-145.3924369, -15.2912173], [-145.356281, -15.3036575], [-145.3215643, -15.3228343], [-145.2893827, -15.3496686], [-145.259258499999987, -15.3891598], [-145.2435323, -15.4220204], [-145.2331231, -15.4600019], [-145.22969710000001, -15.5071632], [-145.24365610000001, -15.5709828], [-145.2556684, -15.5959883], [-145.180382900000012, -15.5768111], [-145.134929699999986, -15.5744293], [-145.0919198, -15.5803785], [-145.0175939, -15.604438], [-144.973277200000012, -15.6327065], [-144.9266419, -15.6863969], [-144.9108489, -15.7170726], [-144.8950466, -15.7696123], [-144.8812983, -15.7900623], [-144.857967699999989, -15.8416481], [-144.8462963, -15.8900978], [-144.7873783, -15.9107632], [-144.7956734, -15.8922377], [-144.8289543, -15.8492068], [-144.8478773, -15.8089948], [-144.8575984, -15.7730366], [-144.8605192, -15.7421409], [-144.8555676, -15.6911526], [-144.8310059, -15.6269103], [-144.807681300000013, -15.5935841], [-144.785773, -15.5715208], [-144.7455635, -15.5440029], [-144.7024716, -15.5270648], [-144.6731436, -15.5210669], [-144.6150869, -15.5212662], [-144.5569985, -15.5363325], [-144.5223899, -15.5533518], [-144.4783617, -15.5864583], [-144.446100199999989, -15.6215691], [-144.418925, -15.6653385], [-144.4010351, -15.7288426], [-144.400166500000012, -15.7647475], [-144.4050236, -15.7980288], [-144.41559190000001, -15.8300513], [-144.4383681, -15.8701771], [-144.4687382, -15.9033322], [-144.51589, -15.9356273], [-144.578501, -15.9583431], [-144.620757200000014, -15.9630286], [-144.6687516, -15.960666], [-144.7030052, -15.9523444], [-144.6400744, -16.006311], [-144.611709100000013, -16.0442682], [-144.5871989, -16.0939591], [-144.570927, -16.1666649], [-144.5679189, -16.1961347], [-144.5443564, -16.1784164], [-144.4955699, -16.1537421], [-144.4569449, -16.1423772], [-144.4047444, -16.1377931], [-144.372442, -16.1402518], [-144.319513199999989, -16.1537853], [-144.2858343, -16.1691563], [-144.207365, -16.2143064], [-144.1821342, -16.2351926], [-144.115410700000012, -16.3051868], [-144.0697643, -16.2699985], [-144.0363963, -16.2537832], [-143.9659412, -16.2366033], [-143.9105821, -16.2361773], [-143.8511928, -16.2449694], [-143.7814692, -16.26472], [-143.726199900000012, -16.2932695], [-143.701216100000011, -16.3124055], [-143.6563414, -16.3643953], [-143.598382, -16.3868751], [-143.542698, -16.4161156], [-143.503813400000013, -16.4067448], [-143.4622851, -16.4043122], [-143.405196, -16.409849], [-143.4184821, -16.3814602], [-143.4355851, -16.330158], [-143.4398297, -16.2965183], [-143.4342718, -16.2416945], [-143.4146886, -16.1920581], [-143.395404899999988, -16.1637787], [-143.3611809, -16.129733], [-143.321518, -16.1043673], [-143.2895045, -16.0913063], [-143.2319574, -16.0790604], [-143.163414, -16.0789848], [-143.1143137, -16.0897239], [-143.0698459, -16.1100044], [-143.020765399999988, -16.1436162], [-142.9544043, -16.1728127], [-142.89029450000001, -16.2167493], [-142.860656400000011, -16.2427056], [-142.823242599999986, -16.2941566], [-142.801796599999989, -16.3584444], [-142.7996852, -16.4015293], [-142.8036174, -16.4315291], [-142.7380322, -16.453588], [-142.689423299999987, -16.483972], [-142.6531422, -16.517083], [-142.620373699999988, -16.5679571], [-142.610126, -16.5951549], [-142.5796584, -16.6531141], [-142.5694212, -16.6981687], [-142.5690354, -16.7461788], [-142.5801535, -16.7947823], [-142.6059588, -16.8445695], [-142.634408900000011, -16.8780869], [-142.69091370000001, -16.918853], [-142.732370300000014, -16.9348365], [-142.788658700000013, -16.9425501], [-142.8514394, -16.958818], [-142.84646, -17.0077222], [-142.8556592, -17.0675983], [-142.8413559, -17.0951651], [-142.8228662, -17.1646111], [-142.822692499999988, -17.2108671], [-142.8289476, -17.2439445], [-142.843445, -17.2831248], [-142.8744592, -17.330271], [-142.9014105, -17.3565415], [-142.945497100000011, -17.3855311], [-143.0046868, -17.4074438], [-143.0402552, -17.41241], [-143.0854348, -17.4108656], [-143.1586608, -17.3942041], [-143.1942192, -17.3768109], [-143.250460299999986, -17.3375516], [-143.279065, -17.3099323], [-143.312294400000013, -17.2554101], [-143.3503165, -17.2356356], [-143.3926826, -17.2070362], [-143.457285500000012, -17.1460585], [-143.4837066, -17.1109567], [-143.5177773, -17.0434862], [-143.5328623, -16.9935975], [-143.5394554, -16.9473475], [-143.5666013, -16.9395547], [-143.6069333, -16.9207768], [-143.654962899999987, -16.9031758], [-143.7254465, -16.8674505], [-143.7598939, -16.8580628], [-143.8326749, -16.825816], [-143.873489299999989, -16.8023099], [-143.8919816, -16.8426553], [-143.934133800000012, -16.8945231], [-143.9732405, -16.9226089], [-144.0055404, -16.9379149], [-144.0466396, -16.9497118], [-144.1084381, -16.9530241], [-144.1216416, -16.9673869], [-144.1001899, -17.0210078], [-144.0934866, -17.0611083], [-144.0934301, -17.0987494], [-144.1088153, -17.1654693], [-144.13169, -17.2088254], [-144.1505979, -17.2604007], [-144.1881319, -17.3128238], [-144.2364657, -17.3495143], [-144.2730913, -17.366032], [-144.3064781, -17.3747369], [-144.366703, -17.3787355], [-144.4106844, -17.3730156], [-144.4570512, -17.3575709], [-144.5189117, -17.326213], [-144.564408500000013, -17.2874684], [-144.587830700000012, -17.2557711], [-144.620484, -17.1969249], [-144.6771488, -17.1963124], [-144.70700690000001, -17.1925585], [-144.77381, -17.1737773], [-144.8185614, -17.1548622], [-144.8646836, -17.1306421], [-144.905928100000011, -17.1039157], [-144.9362356, -17.1003924], [-144.9928807, -17.0816606], [-145.0245012, -17.0629689], [-145.0663926, -17.045893], [-145.1156126, -17.0107547], [-145.2277033, -17.0182028], [-145.2572614, -17.0154574], [-145.3000759, -17.003762], [-145.3449762, -16.9804638], [-145.417089800000014, -16.9540261], [-145.4504401, -16.9335606], [-145.4913148, -16.8988175], [-145.5269961, -16.8528204], [-145.5561486, -16.7865903], [-145.5655679, -16.7385639], [-145.6264708, -16.7099804], [-145.6832704, -16.6652063], [-145.7272908, -16.6225092], [-145.8019127, -16.5604091], [-145.855768, -16.4985738], [-145.8860253, -16.4672788], [-145.946456500000011, -16.3944413], [-145.968321300000014, -16.3563848], [-145.989173099999988, -16.304874], [-146.021087, -16.2387364], [-146.1076665, -16.2091623], [-146.1268483, -16.2667553], [-146.1500256, -16.3032227], [-146.173107, -16.3282073], [-146.208717299999989, -16.3553691], [-146.235582099999988, -16.3691668], [-146.2790726, -16.3823699], [-146.3495159, -16.3897531], [-146.4116347, -16.3854127], [-146.449786100000011, -16.3737836], [-146.4968611, -16.3472364], [-146.5436508, -16.3014548], [-146.5726424, -16.2591575], [-146.591690199999988, -16.2210284], [-146.6026125, -16.1831211], [-146.6056194, -16.1413215], [-146.59832, -16.0925114], [-146.5832806, -16.0538189], [-146.641942699999987, -16.0457649], [-146.7699972, -16.0121616], [-146.8702894, -15.9675987], [-146.9061958, -15.9489172], [-146.9787489, -15.9016572], [-147.016966200000013, -15.8642707], [-147.062641500000012, -15.802301], [-147.0813868, -15.7625445], [-147.0957098, -15.7010429], [-147.0962261, -15.6612783], [-147.087803400000013, -15.6148725], [-147.0733587, -15.5759821], [-147.052667500000013, -15.5423222], [-147.0144965, -15.5025544], [-147.0648228, -15.4231535], [-147.099509, -15.4505396], [-147.1348817, -15.4684376], [-147.1809371, -15.4814664], [-147.2312653, -15.508175], [-147.2831214, -15.5221369], [-147.3220172, -15.5253866], [-147.3753376, -15.5232652], [-147.419848699999989, -15.5151742], [-147.4842858, -15.5175009], [-147.528878, -15.5123367], [-147.5712627, -15.4979903], [-147.637229100000013, -15.4612751], [-147.6641115, -15.4397817], [-147.7417321, -15.4465361], [-147.791827899999987, -15.4387895], [-147.82428010000001, -15.4276409], [-147.870959, -15.4015766], [-147.9649335, -15.3727188], [-148.0268987, -15.3345876], [-148.0814308, -15.2826109], [-148.1629757, -15.3166263], [-148.1946806, -15.3242077], [-148.2411076, -15.3268177], [-148.2938206, -15.3181943], [-148.3572115, -15.2887738], [-148.3936467, -15.259343], [-148.4303075, -15.217739], [-148.4658412, -15.1576777], [-148.4908058, -15.0931543], [-148.4971899, -15.0548044], [-148.5207729, -15.0711669], [-148.5647203, -15.0910904], [-148.6216939, -15.107591], [-148.685429199999987, -15.1111541], [-148.7455793, -15.1003161], [-148.81168120000001, -15.0722602], [-148.8466386, -15.0482092], [-148.877787500000011, -15.0168635], [-148.899000300000012, -14.9841066], [-148.9142386, -14.94497], [-148.9237939, -14.8775793]], [[-145.4133488, -16.0131164], [-145.4082913, -16.0347654], [-145.3850663, -16.0723265], [-145.3610707, -16.1440363], [-145.338227100000012, -16.1682642], [-145.3115004, -16.2114131], [-145.2437366, -16.2661479], [-145.1970229, -16.3213647], [-145.177602, -16.3523329], [-145.1584736, -16.4035543], [-145.1526849, -16.4517109], [-145.1607072, -16.5087558], [-145.120420599999989, -16.517607], [-145.0664286, -16.5369908], [-145.0118458, -16.5665047], [-144.986374500000011, -16.5859049], [-144.8975941, -16.5879124], [-144.8613393, -16.5781054], [-144.8224132, -16.5732064], [-144.76060720000001, -16.5730313], [-144.7155142, -16.5803182], [-144.669753, -16.5971271], [-144.634910600000012, -16.6161435], [-144.5783826, -16.6685938], [-144.5423882, -16.6780314], [-144.489762399999989, -16.6986872], [-144.467543299999988, -16.7116185], [-144.4525621, -16.6909313], [-144.4542075, -16.6751211], [-144.499956, -16.6491771], [-144.536987900000014, -16.6223467], [-144.6031145, -16.558745], [-144.6242914, -16.5323655], [-144.6469224, -16.4912805], [-144.6674026, -16.4308751], [-144.671511, -16.4039145], [-144.6965155, -16.4281082], [-144.7392795, -16.4566231], [-144.7747087, -16.4719716], [-144.828552699999989, -16.4837517], [-144.9052767, -16.4812212], [-144.964481400000011, -16.4644972], [-144.9955974, -16.450351], [-145.060493900000012, -16.4134649], [-145.104968500000012, -16.3775538], [-145.1450251, -16.3290669], [-145.1893591, -16.2616214], [-145.206981500000012, -16.2214329], [-145.2178427, -16.1617256], [-145.2824384, -16.128153], [-145.38879080000001, -16.0407062], [-145.4133488, -16.0131164]], [[-143.1798489, -16.6096972], [-143.170905, -16.6574984], [-143.1708298, -16.6823036], [-143.1783313, -16.724987], [-143.1293229, -16.7316022], [-143.08454660000001, -16.7455888], [-143.083418099999989, -16.6937985], [-143.0867187, -16.660187], [-143.081767500000012, -16.6128539], [-143.107903, -16.6074494], [-143.1410271, -16.6111253], [-143.1798489, -16.6096972]]], [[[-141.642789, -14.1050844], [-141.635128, -14.0392552], [-141.6160003, -13.9938264], [-141.5960361, -13.9653714], [-141.563476799999989, -13.9343725], [-141.5276853, -13.9122752], [-141.4647699, -13.8928356], [-141.3987184, -13.8935614], [-141.3676149, -13.9010842], [-141.326615800000013, -13.9191501], [-141.2854278, -13.950022], [-141.23931540000001, -13.9464429], [-141.176288699999986, -13.9566242], [-141.116285800000014, -13.978536], [-141.082258, -14.0001597], [-141.0458159, -14.0291806], [-141.019264600000014, -14.0565227], [-140.9882355, -14.1036523], [-140.9710725, -14.154924], [-140.967504100000014, -14.1995267], [-140.9730453, -14.2389474], [-140.982927100000012, -14.2691773], [-141.0026526, -14.3056735], [-141.0325731, -14.3410633], [-141.0575179, -14.3611829], [-141.093167099999988, -14.3812872], [-141.1272223, -14.3929565], [-141.169429799999989, -14.399486], [-141.275241200000011, -14.3930126], [-141.3327172, -14.3772481], [-141.3735949, -14.3541926], [-141.4237775, -14.3112979], [-141.460644800000011, -14.3079557], [-141.509134499999988, -14.2931068], [-141.551902899999988, -14.2691499], [-141.5810559, -14.2445287], [-141.6086101, -14.2109377], [-141.6271585, -14.1766136], [-141.638901, -14.1391452], [-141.642789, -14.1050844]]], [[[-139.0549494, -14.8129205], [-139.044191500000011, -14.7528191], [-139.0226896, -14.7079577], [-139.0045141, -14.6839894], [-138.96609, -14.6472149], [-138.923573299999987, -14.6204741], [-138.8936885, -14.6084511], [-138.8474364, -14.5976601], [-138.7883635, -14.5983984], [-138.7483131, -14.6081328], [-138.7110658, -14.6253642], [-138.6843304, -14.6437306], [-138.6349514, -14.6925964], [-138.5979635, -14.7518418], [-138.583781499999986, -14.8037343], [-138.5824878, -14.843222], [-138.59625, -14.9051315], [-138.615033, -14.9430484], [-138.6595675, -14.9939268], [-138.7051482, -15.0223824], [-138.7614031, -15.0392488], [-138.8043141, -15.0422379], [-138.8639287, -15.0337408], [-138.9092726, -15.0160266], [-138.9532183, -14.9920114], [-138.9867118, -14.9663897], [-139.024773399999987, -14.9214915], [-139.04862510000001, -14.8657023], [-139.0549494, -14.8129205]]], [[[-140.3769547, -15.9851594], [-140.3666443, -15.9190664], [-140.349576399999989, -15.8806997], [-140.307875200000012, -15.829221], [-140.2766545, -15.8057643], [-140.2111531, -15.7763056], [-140.1514508, -15.7649037], [-140.108607, -15.7639958], [-140.069279099999989, -15.7682078], [-140.0265896, -15.7786453], [-139.974819599999989, -15.8050222], [-139.9384389, -15.8368312], [-139.9142765, -15.8692158], [-139.89987, -15.8976373], [-139.887227700000011, -15.9424514], [-139.8853645, -15.9966091], [-139.8952725, -16.0426717], [-139.913162699999987, -16.0822476], [-139.955829, -16.1361851], [-140.010739199999989, -16.1769867], [-140.054168, -16.1959816], [-140.0990382, -16.2069831], [-140.1602208, -16.2089835], [-140.198874600000011, -16.2027757], [-140.2504539, -16.1846471], [-140.2846037, -16.1644061], [-140.3189083, -16.1338106], [-140.347264700000011, -16.0958225], [-140.371555199999989, -16.0330548], [-140.3769547, -15.9851594]]], [[[-142.739431599999989, -16.1641417], [-142.735904299999987, -16.1230125], [-142.7232894, -16.0812411], [-142.7038375, -16.04566], [-142.6807901, -15.9865906], [-142.652028699999988, -15.9306218], [-142.6020738, -15.8702978], [-142.5231187, -15.7970878], [-142.4516932, -15.753245], [-142.4248598, -15.7084701], [-142.3982428, -15.6786795], [-142.340971599999989, -15.6335213], [-142.2938373, -15.5843414], [-142.249006, -15.5576324], [-142.201373600000011, -15.5392529], [-142.160358800000012, -15.5315506], [-142.111860400000012, -15.5305254], [-142.063190100000014, -15.5396092], [-142.030904, -15.552316], [-141.9993596, -15.5714049], [-141.9661305, -15.6013514], [-141.9404802, -15.6375889], [-141.925054499999987, -15.6736701], [-141.9157849, -15.7395187], [-141.9208964, -15.7786484], [-141.9447831, -15.8381651], [-141.9719269, -15.8761736], [-142.056956, -15.9675497], [-142.0804635, -15.9983115], [-142.1134304, -16.0273158], [-142.13570820000001, -16.0869302], [-142.1713748, -16.1599795], [-142.1796534, -16.1860054], [-142.203386599999988, -16.2357295], [-142.2257177, -16.2714326], [-142.2827907, -16.3531937], [-142.327169199999986, -16.3974282], [-142.361097699999988, -16.4193536], [-142.413140199999987, -16.4389977], [-142.4524504, -16.4459233], [-142.5080672, -16.4469296], [-142.5714036, -16.4324576], [-142.6083995, -16.4142783], [-142.6579516, -16.372257], [-142.6784836, -16.3447422], [-142.698230099999989, -16.30561], [-142.7117251, -16.2613064], [-142.725039900000013, -16.233582], [-142.736601799999988, -16.1932135], [-142.739431599999989, -16.1641417]]], [[[-148.491090500000013, -15.8438654], [-148.4889863, -15.8192191], [-148.4717052, -15.7462612], [-148.4480824, -15.7005053], [-148.4279238, -15.6754749], [-148.3919387, -15.6446305], [-148.3557107, -15.6247713], [-148.2885794, -15.6065816], [-148.2405992, -15.6062247], [-148.201004899999987, -15.6138025], [-148.1681802, -15.626429], [-148.12352150000001, -15.655396], [-148.0674056, -15.7097521], [-148.0371979, -15.7508281], [-148.021547, -15.7869984], [-148.0121208, -15.8465773], [-148.018772399999989, -15.8982568], [-148.0318599, -15.9347838], [-148.0490547, -15.9649984], [-148.074636, -15.9981643], [-148.1051163, -16.0249885], [-148.166309, -16.0583299], [-148.2276086, -16.0724999], [-148.2694917, -16.0725701], [-148.3165324, -16.0633531], [-148.3742235, -16.0373422], [-148.4165275, -16.00582], [-148.4564781, -15.9600916], [-148.4845852, -15.8977724], [-148.491090500000013, -15.8438654]]], [[[-141.1094417, -15.8222334], [-141.0995101, -15.7632573], [-141.0781915, -15.7178995], [-141.059636899999987, -15.6926237], [-141.0312959, -15.665379], [-140.9936147, -15.6416813], [-140.895271400000013, -15.6082784], [-140.851351, -15.6016212], [-140.8174056, -15.6024199], [-140.7703315, -15.6123053], [-140.73060430000001, -15.6297564], [-140.685683399999988, -15.6633595], [-140.6678809, -15.6830772], [-140.639584500000012, -15.7307824], [-140.628949799999987, -15.7632024], [-140.623211199999986, -15.8054635], [-140.6295706, -15.8619723], [-140.6490602, -15.913191], [-140.6887082, -15.9677015], [-140.7222253, -15.9956664], [-140.7849163, -16.0271069], [-140.827414, -16.0382205], [-140.8894856, -16.0415661], [-140.9375904, -16.033608], [-140.9798353, -16.0179164], [-141.011608200000012, -15.999974], [-141.054675, -15.9637647], [-141.07566030000001, -15.9366042], [-141.0979321, -15.8916421], [-141.1060186, -15.8614345], [-141.1094417, -15.8222334]]], [[[-144.7707316, -14.9600442], [-144.768531, -14.9304339], [-144.758844900000014, -14.8927613], [-144.736451100000011, -14.8493766], [-144.7080066, -14.81263], [-144.6759678, -14.7846237], [-144.6455501, -14.7665969], [-144.610016699999989, -14.7529189], [-144.5644354, -14.7435225], [-144.5262775, -14.7429438], [-144.4905367, -14.7483102], [-144.4441084, -14.7646577], [-144.416522500000013, -14.7800855], [-144.3817891, -14.8084207], [-144.3650178, -14.8275985], [-144.341594500000014, -14.8666369], [-144.3323465, -14.8911101], [-144.32430260000001, -14.9351029], [-144.3310534, -15.0001246], [-144.3497318, -15.0454715], [-144.3689815, -15.0735977], [-144.408319400000011, -15.1103888], [-144.4552569, -15.1380339], [-144.5179914, -15.1570336], [-144.5852142, -15.1589146], [-144.621646, -15.1519657], [-144.6577376, -15.1380804], [-144.7123511, -15.0990985], [-144.740592099999986, -15.0638547], [-144.7655815, -15.0043332], [-144.7707316, -14.9600442]]], [[[-145.469432899999987, -14.693116], [-145.4657057, -14.6588725], [-145.4444101, -14.5954278], [-145.4392655, -14.5685916], [-145.4240955, -14.5286642], [-145.3946884, -14.4819699], [-145.3289282, -14.4129231], [-145.2852393, -14.3841517], [-145.213661, -14.3569522], [-145.1794246, -14.3161558], [-145.1510848, -14.2929381], [-145.09351860000001, -14.2535105], [-145.0555918, -14.2319536], [-144.9670789, -14.1992573], [-144.9135915, -14.1879911], [-144.8603636, -14.1881533], [-144.8327864, -14.1917807], [-144.7870917, -14.2052944], [-144.7531683, -14.222441], [-144.721583399999986, -14.2458092], [-144.6946379, -14.2744728], [-144.6678795, -14.3180232], [-144.655385, -14.3523398], [-144.648915, -14.3894342], [-144.6496378, -14.4275567], [-144.663406400000014, -14.4812178], [-144.68447, -14.5195207], [-144.729761599999989, -14.5659679], [-144.7840664, -14.5977315], [-144.8372861, -14.6422379], [-144.9298255, -14.6897736], [-144.9735219, -14.7044625], [-145.0074718, -14.7509443], [-145.0692927, -14.8291488], [-145.0988385, -14.8576353], [-145.1463257, -14.8892757], [-145.1710391, -14.9003692], [-145.2182204, -14.9120525], [-145.276190500000013, -14.9117669], [-145.3165148, -14.9022548], [-145.375713499999989, -14.8708836], [-145.412230599999987, -14.8370111], [-145.4312928, -14.8142038], [-145.4559286, -14.7686612], [-145.4677346, -14.7225932], [-145.469432899999987, -14.693116]]], [[[-146.6099053, -14.5518711], [-146.606673, -14.520099], [-146.5963346, -14.4829109], [-146.577931400000011, -14.4423899], [-146.5567202, -14.3805057], [-146.5285189, -14.339137], [-146.4882227, -14.2975309], [-146.4428804, -14.2673045], [-146.3702265, -14.2398405], [-146.3322497, -14.2319825], [-146.270015699999988, -14.2250246], [-146.2253928, -14.2263688], [-146.1584373, -14.244301], [-146.053077699999989, -14.1876912], [-146.015581700000013, -14.1654559], [-145.9815921, -14.1503389], [-145.9226208, -14.1343122], [-145.8857425, -14.1290613], [-145.83872980000001, -14.1291406], [-145.8010783, -14.1364791], [-145.7486231, -14.1590614], [-145.7176561, -14.1811312], [-145.682554, -14.2190127], [-145.6450504, -14.2853967], [-145.6315601, -14.3314296], [-145.628691300000014, -14.3645478], [-145.6341344, -14.4119292], [-145.6441302, -14.4428846], [-145.6621328, -14.4769068], [-145.698865399999988, -14.521522], [-145.7438553, -14.5631382], [-145.793217199999987, -14.596264], [-145.8448377, -14.6246436], [-145.8736405, -14.6359918], [-145.9577957, -14.6582866], [-146.017501399999986, -14.6675028], [-146.0565527, -14.6673958], [-146.114103199999988, -14.6561921], [-146.162746199999987, -14.6907275], [-146.194940300000013, -14.7062751], [-146.254447199999987, -14.7209268], [-146.3143873, -14.7542438], [-146.372498900000011, -14.7673741], [-146.424673, -14.7661403], [-146.4710196, -14.7545057], [-146.5055916, -14.7382197], [-146.5567356, -14.696404], [-146.5840091, -14.6575552], [-146.6050263, -14.602128], [-146.6099053, -14.5518711]]], [[[-135.3282126, -23.1752068], [-135.3195227, -23.1173984], [-135.293882, -23.0644943], [-135.2684003, -23.0342154], [-135.1698208, -22.9425566], [-135.130016, -22.8856165], [-135.082587100000012, -22.8407728], [-135.0404078, -22.8178945], [-134.987932300000011, -22.8039984], [-134.9515082, -22.8020502], [-134.8937603, -22.8101131], [-134.8320163, -22.8330316], [-134.783230300000014, -22.8631162], [-134.7380689, -22.9146094], [-134.7214004, -22.9480774], [-134.6902211, -22.973149], [-134.6677441, -22.9992983], [-134.643067800000011, -23.0439349], [-134.632463, -23.0809928], [-134.6292301, -23.1253934], [-134.6353389, -23.1660642], [-134.5920471, -23.1384102], [-134.5292358, -23.1190003], [-134.4716223, -23.116629], [-134.4310755, -23.1223055], [-134.395922500000012, -23.1339436], [-134.348488, -23.1621177], [-134.318478699999986, -23.1910083], [-134.2785546, -23.241676], [-134.2563537, -23.2852935], [-134.2462415, -23.3279539], [-134.2451108, -23.363704], [-134.2547036, -23.4141989], [-134.2776792, -23.4646635], [-134.294895200000013, -23.4888914], [-134.340204199999988, -23.5297413], [-134.4052575, -23.5627595], [-134.4470972, -23.5732448], [-134.5140471, -23.5729367], [-134.5540245, -23.5627527], [-134.6071679, -23.5351206], [-134.6546486, -23.4883378], [-134.6814817, -23.439916], [-134.7024118, -23.3830218], [-134.7087405, -23.3532422], [-134.740620400000012, -23.3782624], [-134.7988542, -23.4058154], [-134.8937009, -23.4372019], [-134.9269859, -23.4449226], [-134.997114399999987, -23.4440569], [-135.0404039, -23.431448], [-135.1511745, -23.3805043], [-135.2199592, -23.3537948], [-135.2495309, -23.3337418], [-135.2911509, -23.2892721], [-135.3103648, -23.2558388], [-135.323101400000013, -23.2188079], [-135.3282126, -23.1752068]]], [[[-137.3587535, -23.1669202], [-137.352205700000013, -23.1117628], [-137.335235899999986, -23.0635362], [-137.3185111, -23.0348068], [-137.293900799999989, -23.005277], [-137.2679221, -22.9833191], [-137.2248199, -22.9557085], [-137.1640802, -22.9345645], [-137.104643399999986, -22.9315157], [-137.0433598, -22.9460064], [-137.00660160000001, -22.964741], [-136.973356700000011, -22.9908705], [-136.9484024, -23.019071], [-136.921297399999986, -23.0643267], [-136.9050485, -23.1236838], [-136.905209500000012, -23.1760878], [-136.922377399999988, -23.235781], [-136.9588192, -23.2985813], [-136.9867021, -23.3291112], [-137.0232862, -23.3552812], [-137.0554948, -23.3701126], [-137.1103, -23.382744], [-137.1506738, -23.3832225], [-137.2078122, -23.3712556], [-137.2565289, -23.3479861], [-137.3002812, -23.3127072], [-137.3363684, -23.2610159], [-137.3546087, -23.2080028], [-137.3587535, -23.1669202]]], [[[-140.893228099999988, -21.6838574], [-140.8880044, -21.6403534], [-140.8708567, -21.594622], [-140.8358748, -21.5468793], [-140.8122237, -21.5074589], [-140.7835006, -21.4768704], [-140.751004099999989, -21.4536559], [-140.7129282, -21.4364289], [-140.6834393, -21.4285848], [-140.630946099999989, -21.4240676], [-140.5622874, -21.4322979], [-140.514216299999987, -21.45099], [-140.479771699999986, -21.4737953], [-140.4435815, -21.5116456], [-140.426549200000011, -21.5388729], [-140.410458799999986, -21.5795337], [-140.387817899999988, -21.6114856], [-140.3703628, -21.6520672], [-140.362133300000011, -21.7051314], [-140.3640987, -21.7362914], [-140.374774, -21.7782772], [-140.3894146, -21.8088137], [-140.4214495, -21.8499322], [-140.4477214, -21.8724738], [-140.4810545, -21.8934453], [-140.5266861, -21.9117089], [-140.582569, -21.9253273], [-140.6180115, -21.9281128], [-140.663389, -21.9230194], [-140.703832799999986, -21.9099756], [-140.7815565, -21.8752474], [-140.8110959, -21.8535725], [-140.8455384, -21.8185057], [-140.8687194, -21.7818678], [-140.8824196, -21.7495101], [-140.893228099999988, -21.6838574]]], [[[-139.249062400000014, -21.8827769], [-139.242999, -21.8324792], [-139.227453, -21.7916076], [-139.203103, -21.7549637], [-139.1675813, -21.7205878], [-139.124249600000013, -21.689215], [-139.0885654, -21.6714439], [-139.070509499999986, -21.6513863], [-139.0206605, -21.6115358], [-138.9792387, -21.59124], [-138.9443865, -21.5819496], [-138.8894072, -21.5779831], [-138.8532408, -21.5814937], [-138.7907093, -21.5981495], [-138.759938799999986, -21.6130984], [-138.6987772, -21.6354627], [-138.6659439, -21.6569195], [-138.6215225, -21.6995927], [-138.5939347, -21.740642], [-138.579519299999987, -21.7769079], [-138.5721284, -21.8185682], [-138.573455700000011, -21.8590732], [-138.5852109, -21.905058], [-138.600889599999988, -21.9366304], [-138.6429116, -21.9860348], [-138.674609, -22.0088497], [-138.6172723, -22.0380878], [-138.5929583, -22.0571371], [-138.5433382, -22.1086211], [-138.512821300000013, -22.1562455], [-138.4958179, -22.2204272], [-138.4994269, -22.2848548], [-138.510795300000012, -22.3275977], [-138.5336029, -22.3718052], [-138.5631933, -22.4058798], [-138.588312300000013, -22.426106], [-138.627395400000012, -22.447527], [-138.6847252, -22.4706144], [-138.7342544, -22.4821353], [-138.7699499, -22.4830413], [-138.8330637, -22.4703335], [-138.8717059, -22.4516412], [-138.917728899999986, -22.4135818], [-138.9385955, -22.385929], [-138.959126199999986, -22.3418198], [-138.9799071, -22.3074774], [-138.9952467, -22.2604581], [-138.998529, -22.2310007], [-138.9959672, -22.1893865], [-138.977385700000013, -22.133552], [-138.943576400000012, -22.0861523], [-139.0100272, -22.0922769], [-139.050505, -22.0897672], [-139.083316200000013, -22.0822247], [-139.1404908, -22.0597569], [-139.1731873, -22.0378645], [-139.1974811, -22.0147292], [-139.2214459, -21.9824742], [-139.2413584, -21.9367759], [-139.249062400000014, -21.8827769]]], [[[-136.4137901, -22.0273844], [-136.4116543, -21.9947398], [-136.4027624, -21.9558956], [-136.3753369, -21.8978841], [-136.3472272, -21.8636864], [-136.3132989, -21.8343802], [-136.2662661, -21.8077653], [-136.2032922, -21.7916352], [-136.1672575, -21.7907425], [-136.1069872, -21.8032332], [-136.0649261, -21.8234921], [-136.040390800000011, -21.8414073], [-136.0124655, -21.8703769], [-135.9901958, -21.9052227], [-135.9725116, -21.9546321], [-135.966156, -22.00497], [-135.969488399999989, -22.0445673], [-135.9813485, -22.085542], [-136.011671400000012, -22.1447347], [-136.0376707, -22.1757359], [-136.087821600000012, -22.2126067], [-136.1283487, -22.2294245], [-136.1585277, -22.2360769], [-136.1997202, -22.2380469], [-136.2565908, -22.2290761], [-136.299072599999988, -22.2115087], [-136.3365085, -22.186457], [-136.3782364, -22.1404281], [-136.3985822, -22.1018451], [-136.4112951, -22.0566473], [-136.4137901, -22.0273844]]], [[[-135.852261700000014, -21.4793715], [-135.8504341, -21.4547835], [-135.8350145, -21.4008781], [-135.815086, -21.3661441], [-135.7767419, -21.3252714], [-135.748213099999987, -21.3058681], [-135.7066222, -21.2873206], [-135.6650457, -21.2776517], [-135.6262769, -21.2754113], [-135.5822226, -21.2813343], [-135.5397974, -21.2747669], [-135.480358700000011, -21.2788559], [-135.4378317, -21.2919503], [-135.3624979, -21.3320424], [-135.323502, -21.3627448], [-135.2786927, -21.4177501], [-135.255305, -21.4683026], [-135.2474977, -21.5036186], [-135.2462906, -21.5392439], [-135.2553443, -21.5892196], [-135.271530399999989, -21.6263128], [-135.2914884, -21.6556724], [-135.335091799999987, -21.6955135], [-135.3758458, -21.7176137], [-135.4159903, -21.7294567], [-135.4564273, -21.754142], [-135.5090705, -21.7706014], [-135.5492367, -21.7737564], [-135.651812, -21.7632628], [-135.708595800000012, -21.7432527], [-135.73766470000001, -21.7253056], [-135.778212, -21.6890007], [-135.7997585, -21.6608915], [-135.823786399999989, -21.6120844], [-135.837905, -21.5696685], [-135.8495294, -21.5137609], [-135.852261700000014, -21.4793715]]], [[[-136.9663026, -21.2969446], [-136.9590556, -21.2486386], [-136.9467338, -21.2161782], [-136.916092, -21.1695946], [-136.8883956, -21.1432693], [-136.8424499, -21.1147409], [-136.802944200000013, -21.1006406], [-136.7541271, -21.0933411], [-136.7110729, -21.095738], [-136.6476362, -21.1158517], [-136.6084971, -21.1196135], [-136.5679041, -21.1308886], [-136.527639099999988, -21.1270631], [-136.4660852, -21.1356701], [-136.4333533, -21.1481603], [-136.389484399999986, -21.1760781], [-136.358737600000012, -21.207394], [-136.3303335, -21.2551897], [-136.2687431, -21.2829623], [-136.2298941, -21.3149038], [-136.207545399999987, -21.3423576], [-136.1843557, -21.3851979], [-136.1672431, -21.4332619], [-136.160948, -21.4705153], [-136.1642354, -21.5254671], [-136.1798442, -21.572786], [-136.2077567, -21.6172741], [-136.2559271, -21.6615852], [-136.2815371, -21.676404], [-136.3444667, -21.6967405], [-136.387203, -21.7002019], [-136.4331483, -21.6950845], [-136.5008774, -21.6705319], [-136.5505503, -21.6347137], [-136.5878865, -21.5909231], [-136.6091934, -21.5538261], [-136.62936, -21.5470081], [-136.6754518, -21.5465195], [-136.7387837, -21.5309466], [-136.7696, -21.5160864], [-136.812349, -21.5066539], [-136.8634351, -21.482442], [-136.9162521, -21.4353552], [-136.942142499999989, -21.397738], [-136.954507799999988, -21.3699979], [-136.9651867, -21.3238376], [-136.9663026, -21.2969446]]], [[[-143.7701243, -20.4407225], [-143.7658734, -20.3992974], [-143.7544035, -20.3623887], [-143.7208612, -20.3089887], [-143.6752746, -20.2622901], [-143.6554322, -20.246927], [-143.610665899999987, -20.2238061], [-143.5764881, -20.2142515], [-143.54112, -20.2105005], [-143.4758582, -20.2191829], [-143.438346599999988, -20.2343068], [-143.4126257, -20.2501536], [-143.363809, -20.2950239], [-143.3437121, -20.3207088], [-143.320244300000013, -20.3681082], [-143.3118067, -20.4038516], [-143.2863748, -20.401959], [-143.236383600000011, -20.4064381], [-143.206465900000012, -20.4147144], [-143.164839699999987, -20.4350031], [-143.134321300000011, -20.4578906], [-143.1024708, -20.494416], [-143.058109699999989, -20.489088], [-143.0030882, -20.4954573], [-142.96933820000001, -20.5063334], [-142.9288812, -20.5285151], [-142.90324480000001, -20.5493892], [-142.871250300000014, -20.5861395], [-142.8523583, -20.6206076], [-142.837661, -20.6679274], [-142.83351540000001, -20.6978569], [-142.8365124, -20.7500857], [-142.8477437, -20.7873406], [-142.866223600000012, -20.8217933], [-142.8877972, -20.8486139], [-142.9190111, -20.8755084], [-142.9688933, -20.9016195], [-143.0033182, -20.9111307], [-143.064492800000011, -20.9136844], [-143.1090707, -20.9047518], [-143.146659199999988, -20.88929], [-143.202103099999988, -20.8518365], [-143.2305605, -20.8229769], [-143.2913278, -20.8300327], [-143.334080300000011, -20.8249599], [-143.373704, -20.8125381], [-143.4043393, -20.7966453], [-143.4522294, -20.7556775], [-143.479651600000011, -20.7166511], [-143.5012692, -20.6573952], [-143.5486869, -20.6588688], [-143.5945673, -20.650404], [-143.6279973, -20.6373588], [-143.6903652, -20.5985185], [-143.7188763, -20.572245], [-143.7522535, -20.521813], [-143.7650501, -20.4845731], [-143.7701243, -20.4407225]]]]}},
            {"id": "987-02", "dpt_id": "987", "numero": 2, "geometry": { "type": "MultiPolygon", "coordinates": [[[[-153.038424099999986, -22.6448564], [-153.0332558, -22.6035292], [-153.0195333, -22.5648842], [-152.9987697, -22.5305092], [-152.9670533, -22.4954454], [-152.9133888, -22.4595129], [-152.868428200000011, -22.4431992], [-152.8282436, -22.4360917], [-152.7675729, -22.4376125], [-152.70395, -22.4551294], [-152.6566583, -22.4823976], [-152.6184552, -22.5200231], [-152.594981, -22.5575912], [-152.5811215, -22.594171], [-152.5740429, -22.657453], [-152.582950899999986, -22.7083866], [-152.610660200000012, -22.765019], [-152.6550566, -22.8130233], [-152.695200699999987, -22.8390314], [-152.748278699999986, -22.85887], [-152.7815199, -22.8643972], [-152.8409259, -22.8625722], [-152.8846514, -22.8519269], [-152.92181930000001, -22.8349273], [-152.9552242, -22.8126504], [-152.994828899999987, -22.7739315], [-153.0262837, -22.7185203], [-153.0370791, -22.6710935], [-153.038424099999986, -22.6448564]]], [[[-143.7366199, -27.8853489], [-143.7316147, -27.8494733], [-143.7048892, -27.78659], [-143.6818625, -27.7530793], [-143.6459423, -27.719938], [-143.5985048, -27.6937027], [-143.5747189, -27.6849674], [-143.520286199999987, -27.6751266], [-143.4864528, -27.6748962], [-143.435683899999987, -27.6814069], [-143.39449590000001, -27.6936837], [-143.353790800000013, -27.7155476], [-143.3128213, -27.7480007], [-143.2937421, -27.7715186], [-143.272501, -27.8093298], [-143.258351, -27.8693321], [-143.2677026, -27.9391259], [-143.29316750000001, -27.9986809], [-143.3206333, -28.0316802], [-143.362451600000014, -28.0644728], [-143.3908535, -28.0786659], [-143.4426899, -28.0947924], [-143.4966506, -28.0990231], [-143.5589449, -28.0897807], [-143.6081044, -28.074115], [-143.6484663, -28.052496], [-143.6727885, -28.0337659], [-143.69941750000001, -28.0045612], [-143.722559600000011, -27.9636127], [-143.735198200000013, -27.9156432], [-143.7366199, -27.8853489]]], [[[-144.606319, -27.5960964], [-144.6009345, -27.5427442], [-144.586761599999988, -27.5014105], [-144.5499747, -27.448013], [-144.5096072, -27.4150526], [-144.4586984, -27.387271], [-144.4255283, -27.3762801], [-144.3608628, -27.3670361], [-144.2883347, -27.3714361], [-144.230578400000013, -27.389373], [-144.169934899999987, -27.4235338], [-144.1377334, -27.4534535], [-144.1117513, -27.4875425], [-144.0915252, -27.5276172], [-144.0821627, -27.5623333], [-144.076523, -27.6303228], [-144.0851313, -27.6856926], [-144.102560899999986, -27.7318278], [-144.127110499999986, -27.7674066], [-144.1605549, -27.7986008], [-144.1890252, -27.8170073], [-144.2313419, -27.8349963], [-144.2780032, -27.8477891], [-144.3295004, -27.8525776], [-144.376470899999987, -27.8477387], [-144.4229651, -27.8343146], [-144.49898, -27.7949174], [-144.5419595, -27.7587943], [-144.5648291, -27.729873], [-144.58778430000001, -27.6896595], [-144.6005375, -27.6530346], [-144.606319, -27.5960964]]], [[[-147.919209, -23.8984786], [-147.9181021, -23.8425525], [-147.9063104, -23.7915065], [-147.8924771, -23.7628372], [-147.8668319, -23.7283508], [-147.8179615, -23.6890638], [-147.7621914, -23.6656038], [-147.7147679, -23.6578015], [-147.6752342, -23.6426374], [-147.6264008, -23.6335001], [-147.5751656, -23.6337578], [-147.547418099999987, -23.638264], [-147.4946783, -23.6550933], [-147.4406533, -23.6887044], [-147.4197957, -23.7089006], [-147.387571, -23.7555024], [-147.3758121, -23.7849503], [-147.367494599999986, -23.835578], [-147.369089300000013, -23.8777934], [-147.3813686, -23.9320347], [-147.410874400000012, -23.9845109], [-147.4435454, -24.0196348], [-147.51139520000001, -24.0640514], [-147.5861301, -24.0938317], [-147.618931800000013, -24.1020814], [-147.6789483, -24.1067595], [-147.7305485, -24.1025889], [-147.763748099999987, -24.0938582], [-147.8109824, -24.0733777], [-147.850709599999988, -24.0460819], [-147.873783800000012, -24.0226716], [-147.8994123, -23.9836653], [-147.912203299999987, -23.9506154], [-147.919209, -23.8984786]]], [[[-149.747968, -23.3680274], [-149.7443637, -23.3331582], [-149.7299868, -23.2896426], [-149.7139712, -23.261796], [-149.6908975, -23.2340028], [-149.638619799999987, -23.1898316], [-149.5675348, -23.1475401], [-149.5034961, -23.1281939], [-149.4498322, -23.1268269], [-149.357258300000012, -23.1451632], [-149.3151057, -23.1611213], [-149.2641133, -23.1941876], [-149.2392337, -23.2190558], [-149.202629699999989, -23.2713829], [-149.1821071, -23.3209423], [-149.1768049, -23.3824287], [-149.1848247, -23.4244188], [-149.214107899999988, -23.4821653], [-149.243502, -23.5144063], [-149.2995808, -23.5505951], [-149.4002342, -23.5877693], [-149.462201099999987, -23.5996681], [-149.5014267, -23.6036552], [-149.5581431, -23.5979255], [-149.6141357, -23.5775261], [-149.6519185, -23.5526323], [-149.7017946, -23.4987682], [-149.7262819, -23.4595938], [-149.7389286, -23.426842], [-149.747968, -23.3680274]]], [[[-151.5927489, -22.4528337], [-151.5890608, -22.4080903], [-151.57641670000001, -22.3670573], [-151.547830299999987, -22.3185416], [-151.506853299999989, -22.2774372], [-151.465899400000012, -22.2525297], [-151.412521, -22.2349091], [-151.3654852, -22.2304824], [-151.3153678, -22.2359864], [-151.2819824, -22.2456929], [-151.2318347, -22.2697996], [-151.1808826, -22.3051892], [-151.1459357, -22.3419858], [-151.1254489, -22.3763603], [-151.111995799999988, -22.4148908], [-151.105723899999987, -22.4728391], [-151.1083092, -22.5169681], [-151.119498, -22.5638704], [-151.1364118, -22.5997121], [-151.1660115, -22.6440045], [-151.1868896, -22.6655859], [-151.222422599999987, -22.6920128], [-151.266143199999988, -22.7124473], [-151.3011452, -22.7215855], [-151.3505376, -22.7253245], [-151.3846628, -22.7217154], [-151.4322425, -22.7078513], [-151.4806883, -22.6810032], [-151.512976, -22.6516757], [-151.5490469, -22.5948028], [-151.585194199999989, -22.505591], [-151.5927489, -22.4528337]]], [[[-154.93605980000001, -21.8143121], [-154.9321664, -21.7755653], [-154.9191566, -21.7356072], [-154.8996349, -21.7019328], [-154.880670900000013, -21.6792915], [-154.8362411, -21.6407706], [-154.790075300000012, -21.6140859], [-154.758449, -21.6032228], [-154.706702799999988, -21.5959101], [-154.6656401, -21.5985884], [-154.62343820000001, -21.6093308], [-154.5815017, -21.6292747], [-154.5456513, -21.6564578], [-154.52156020000001, -21.6825371], [-154.5019144, -21.7118976], [-154.4827704, -21.7609962], [-154.477567599999986, -21.814865], [-154.489076899999986, -21.8736768], [-154.509778, -21.9191859], [-154.535089, -21.95332], [-154.558766, -21.9752909], [-154.593415, -21.9977152], [-154.6346767, -22.014305], [-154.6787493, -22.0224679], [-154.72140490000001, -22.0221383], [-154.7765714, -22.009735], [-154.8466421, -21.9764006], [-154.8756656, -21.9530429], [-154.9091699, -21.9109747], [-154.9231751, -21.8823105], [-154.9334623, -21.8450364], [-154.93605980000001, -21.8143121]]], [[[-149.5963583, -17.6640151], [-149.5716334, -17.6496707], [-149.5285893, -17.653474], [-149.5039056, -17.6610953], [-149.4832418, -17.6444309], [-149.4777379, -17.6182341], [-149.4945684, -17.6126505], [-149.4895291, -17.552328], [-149.5036173, -17.5117024], [-149.4937038, -17.5009794], [-149.4281597, -17.5083217], [-149.3980135, -17.5189726], [-149.3779343, -17.5368053], [-149.3409842, -17.5439049], [-149.3090338, -17.5779567], [-149.300879900000012, -17.6071957], [-149.3112868, -17.6618875], [-149.3036983, -17.6786477], [-149.304863, -17.7216256], [-149.274445, -17.7366149], [-149.2191129, -17.7367169], [-149.212915900000013, -17.7447856], [-149.1572122, -17.7553953], [-149.1275405, -17.7819514], [-149.1247424, -17.8243643], [-149.1436407, -17.8695668], [-149.1605743, -17.8803212], [-149.2189827, -17.8637029], [-149.249559799999986, -17.8611682], [-149.2968917, -17.8196488], [-149.2991848, -17.7891638], [-149.327952399999987, -17.749099], [-149.361388799999986, -17.7608242], [-149.392788700000011, -17.762039], [-149.410559, -17.774176], [-149.4772003, -17.7781752], [-149.4828085, -17.7689179], [-149.5537223, -17.7531675], [-149.5783974, -17.7405359], [-149.5865624, -17.6842432], [-149.5963583, -17.6640151]]]]}},
            {"id": "987-03", "dpt_id": "987", "numero": 3, "geometry": { "type": "MultiPolygon", "coordinates": [[[[-149.5813852, -17.5448667], [-149.5825792, -17.5563973], [-149.521774599999986, -17.5971371], [-149.512820299999987, -17.6234262], [-149.4945684, -17.6126505], [-149.4777379, -17.6182341], [-149.4832418, -17.6444309], [-149.5039056, -17.6610953], [-149.5285893, -17.653474], [-149.5716334, -17.6496707], [-149.5963583, -17.6640151], [-149.6131858, -17.6258377], [-149.6137694, -17.5905964], [-149.6208733, -17.5623657], [-149.6134197, -17.5519992], [-149.5813852, -17.5448667]]], [[[-151.5501212, -16.6201048], [-151.5456993, -16.604077], [-151.5155114, -16.5773987], [-151.4839398, -16.5844802], [-151.442873, -16.6051918], [-151.4371582, -16.6308823], [-151.4573174, -16.6490271], [-151.4562732, -16.6768276], [-151.472043, -16.6823991], [-151.488514400000014, -16.6605908], [-151.5036751, -16.6714631], [-151.5451615, -16.6417057], [-151.5501212, -16.6201048]]], [[[-151.02755160000001, -16.7789733], [-150.9822948, -16.7545427], [-150.9643817, -16.7632476], [-150.958648899999986, -16.7869679], [-150.983207599999986, -16.8105217], [-151.001341700000012, -16.8061796], [-151.02755160000001, -16.7789733]]], [[[-151.493491299999988, -16.7942601], [-151.490006599999987, -16.7463005], [-151.472916199999986, -16.7232946], [-151.443735299999986, -16.7264987], [-151.408005, -16.7864104], [-151.4079963, -16.8045607], [-151.3583501, -16.8351236], [-151.3563421, -16.8638785], [-151.3833232, -16.8769688], [-151.3942396, -16.8909176], [-151.4261248, -16.8927547], [-151.4455877, -16.916984], [-151.4704803, -16.9063437], [-151.45812140000001, -16.889135], [-151.4781757, -16.8502553], [-151.4813596, -16.825892], [-151.493491299999988, -16.7942601]]], [[[-151.0473354, -16.7552992], [-151.03373, -16.7154913], [-151.0408916, -16.7047068], [-151.0024564, -16.6965301], [-150.985791299999988, -16.7018842], [-150.986676100000011, -16.7223917], [-150.9774914, -16.7450107], [-151.0013003, -16.7475919], [-151.02265890000001, -16.7689156], [-151.0473354, -16.7552992]]], [[[-151.763596, -16.4738192], [-151.7466679, -16.4652399], [-151.7226908, -16.4788584], [-151.7202328, -16.5186763], [-151.732632700000011, -16.520961], [-151.7529357, -16.5064722], [-151.7513181, -16.4800991], [-151.763596, -16.4738192]]]]}},
            {"id": "988-01", "dpt_id": "988", "numero": 1, "geometry": {"type": "MultiPolygon", "coordinates": [[[[166.4570625, -22.2228779], [166.4948262, -22.2262117], [166.4964669, -22.2536752], [166.4799009, -22.2568489], [166.460756800000013, -22.2793455], [166.4584619, -22.3106898], [166.4370757, -22.303758], [166.441406199999989, -22.2645445], [166.4269477, -22.2465556], [166.3989767, -22.2349237], [166.431085200000012, -22.2224769], [166.4570625, -22.2228779]]], [[[166.4710939, -20.6997581], [166.5156878, -20.6713433], [166.54620030000001, -20.6349014], [166.5601437, -20.5954324], [166.5605343, -20.5602855], [166.57227850000001, -20.5191934], [166.593341, -20.481324], [166.5921511, -20.4421922], [166.5508184, -20.4042541], [166.5888474, -20.391861], [166.6073897, -20.3936595], [166.6252733, -20.4283412], [166.6582922, -20.4512005], [166.6671347, -20.4661874], [166.6090611, -20.4713577], [166.604426, -20.4854323], [166.5810486, -20.5103623], [166.58199110000001, -20.537108], [166.5715706, -20.5465683], [166.5760508, -20.5693654], [166.5693695, -20.5878889], [166.5839258, -20.6039205], [166.61284280000001, -20.5976035], [166.6093463, -20.6161726], [166.5678374, -20.6882544], [166.5053615, -20.7060615], [166.4710939, -20.6997581]]], [[[167.7937511, -21.0915304], [167.8154667, -21.0858568], [167.8395636, -21.1161721], [167.8234464, -21.1287658], [167.7937511, -21.0915304]]], [[[167.800344200000012, -21.3813244], [167.83895290000001, -21.375015], [167.874326599999989, -21.400139], [167.89654010000001, -21.3982129], [167.8988338, -21.3822229], [167.9459147, -21.3672534], [167.98254270000001, -21.4399213], [167.999671, -21.4578791], [168.0296649, -21.4666688], [168.0545688, -21.4545801], [168.083463200000011, -21.4545907], [168.1149896, -21.4339793], [168.1362245, -21.4484887], [168.1193284, -21.475408], [168.1245554, -21.5027045], [168.113346400000012, -21.5138938], [168.114390500000013, -21.5445257], [168.1081366, -21.5894374], [168.1153606, -21.6273797], [168.048076900000012, -21.6416324], [168.0397538, -21.6584625], [167.9836927, -21.657399], [167.960986600000012, -21.6504746], [167.9355979, -21.6049476], [167.909449200000012, -21.5975158], [167.8639259, -21.5985386], [167.8645626, -21.5749886], [167.878796099999988, -21.5505103], [167.8537732, -21.5270702], [167.832480800000013, -21.4808628], [167.8393362, -21.4516752], [167.8296212, -21.4253409], [167.8076906, -21.4064145], [167.800344200000012, -21.3813244]]], [[[167.0099999, -20.9188888], [167.0410875, -20.9114831], [167.061843900000014, -20.9269346], [167.1240654, -20.9065166], [167.1410648, -20.8724233], [167.1638575, -20.857723], [167.180218599999989, -20.8147775], [167.1705317, -20.7928618], [167.1483354, -20.7835567], [167.1240522, -20.7863878], [167.1017713, -20.7652297], [167.0357496, -20.7795015], [167.0397661, -20.732092], [167.064709, -20.7151918], [167.0999285, -20.7100042], [167.135689, -20.7241062], [167.163008499999989, -20.7117968], [167.1616803, -20.6897916], [167.179613, -20.6807807], [167.211595499999987, -20.6798096], [167.2482225, -20.6955513], [167.2763582, -20.7271479], [167.298144, -20.7268049], [167.3007665, -20.7464436], [167.276128699999987, -20.7640098], [167.2738957, -20.8285801], [167.290513299999986, -20.873331], [167.257395300000013, -20.9072379], [167.2741748, -20.9197909], [167.3016892, -20.9184638], [167.319778899999989, -20.9370063], [167.349934, -20.9383951], [167.3764826, -20.9542404], [167.3852483, -20.9801101], [167.381558, -21.0151614], [167.412088899999986, -21.0350885], [167.4334311, -21.0365585], [167.4584561, -21.066564], [167.4262454, -21.0836256], [167.4086734, -21.0991885], [167.414495499999987, -21.1639099], [167.382314, -21.1835545], [167.338219400000014, -21.1826454], [167.3138976, -21.1516836], [167.3132869, -21.1375764], [167.2672508, -21.1227576], [167.2705025, -21.1021249], [167.2607265, -21.0904169], [167.2160405, -21.0913924], [167.1786247, -21.0832558], [167.1567292, -21.0862376], [167.12716, -21.0703961], [167.111507, -21.0493576], [167.096062, -21.0428571], [167.0891565, -21.0195198], [167.0545888, -20.9875097], [167.0633525, -20.9670697], [167.0519893, -20.947645], [167.0264111, -20.9404863], [167.0099999, -20.9188888]]], [[[167.505174399999987, -22.6887225], [167.517953, -22.6768272], [167.5276001, -22.6434852], [167.5574186, -22.6670682], [167.546287, -22.6947751], [167.505174399999987, -22.6887225]]], [[[167.4132246, -22.6045802], [167.4245529, -22.5877387], [167.4160989, -22.5546341], [167.4658335, -22.5421976], [167.4953519, -22.5594815], [167.5098674, -22.5568051], [167.547294599999987, -22.5961512], [167.5577312, -22.6166358], [167.543993699999987, -22.6294874], [167.5179143, -22.6139213], [167.514543300000014, -22.6342999], [167.5234056, -22.6490834], [167.4929067, -22.6750227], [167.4512957, -22.6661177], [167.429169, -22.6483928], [167.4250525, -22.6184531], [167.4132246, -22.6045802]]]]}},
            {"id": "988-02", "dpt_id": "988", "numero": 2, "geometry": { "type": "MultiPolygon", "coordinates": [[[[164.1559595, -20.0846892], [164.1822953, -20.0783751], [164.216349900000012, -20.1091748], [164.231996900000013, -20.1429792], [164.207226, -20.1434991], [164.1811049, -20.1239509], [164.16358790000001, -20.0853688], [164.1559595, -20.0846892]]], [[[166.7721799, -22.4411543], [166.785250600000012, -22.4334774], [166.776693200000011, -22.4074709], [166.785614399999986, -22.3982807], [166.8393, -22.3974213], [166.8476316, -22.4154598], [166.8330779, -22.4509022], [166.8175536, -22.4665719], [166.7827897, -22.4614331], [166.7721799, -22.4411543]]], [[[164.2713731, -20.2124506], [164.2880673, -20.2228583], [164.300102900000013, -20.2601077], [164.2906864, -20.2613434], [164.2713731, -20.2124506]]], [[[163.570347, -19.5548696], [163.5871895, -19.5547448], [163.610425, -19.5889559], [163.5854783, -19.5951582], [163.570347, -19.5548696]]], [[[166.4948262, -22.2262117], [166.4570625, -22.2228779], [166.437535700000012, -22.1900944], [166.4213866, -22.1735024], [166.3849008, -22.1689048], [166.37207, -22.2071866], [166.3453891, -22.1932437], [166.333509099999986, -22.1973746], [166.3211296, -22.1694752], [166.3234909, -22.152711], [166.2690675, -22.1700276], [166.2221135, -22.1394298], [166.218707, -22.1254282], [166.182529, -22.1053896], [166.1618775, -22.0843172], [166.137722200000013, -22.0982048], [166.1226805, -22.0908285], [166.130698200000012, -22.0638862], [166.145812400000011, -22.074395], [166.162593, -22.0701808], [166.1684367, -22.0298981], [166.1368004, -21.9809553], [166.1478505, -21.9620313], [166.1232522, -21.9472984], [166.0928677, -21.9471691], [166.082016900000013, -21.9363814], [166.0782783, -21.9133694], [166.062046400000014, -21.8977964], [166.0441774, -21.9004932], [166.0189789, -21.9303557], [166.0140481, -21.9479874], [165.9904372, -21.9590534], [165.9780055, -21.9290168], [165.9496385, -21.9253941], [165.9424074, -21.9075575], [165.9067972, -21.8704328], [165.8523898, -21.8586385], [165.842804300000012, -21.8683343], [165.819004299999989, -21.8635337], [165.8332911, -21.8457307], [165.817228, -21.8188046], [165.801713299999989, -21.810503], [165.801762599999989, -21.7900466], [165.760931699999986, -21.7891877], [165.7692949, -21.7669992], [165.7274779, -21.7445789], [165.703298, -21.7504941], [165.6816901, -21.7245057], [165.6616679, -21.7139762], [165.627704, -21.7349228], [165.6242516, -21.710669], [165.60982, -21.7136876], [165.563938799999988, -21.7081164], [165.5311149, -21.6985685], [165.50709470000001, -21.6843536], [165.4718594, -21.6542148], [165.45829040000001, -21.6076147], [165.4368744, -21.6060631], [165.428659, -21.62], [165.3928467, -21.6124117], [165.329265099999986, -21.5866462], [165.2870484, -21.5734803], [165.266922099999988, -21.5567205], [165.260665, -21.5077702], [165.234508299999987, -21.5151351], [165.197273700000011, -21.4846182], [165.1677049, -21.4793849], [165.147871900000013, -21.4606831], [165.137290299999989, -21.4323863], [165.111481, -21.4049999], [165.1281897, -21.3875042], [165.1094697, -21.3675914], [165.094413300000014, -21.3716231], [165.072213, -21.3912179], [165.0458485, -21.3449325], [164.9885032, -21.3132894], [164.9720015, -21.3509321], [164.947123800000014, -21.3567193], [164.9489399, -21.293265], [164.910481800000014, -21.2783032], [164.8942975, -21.2442662], [164.8672483, -21.2277938], [164.8584826, -21.2035809], [164.8326597, -21.183746], [164.8317284, -21.1530188], [164.8611623, -21.1382427], [164.8552637, -21.1038603], [164.838397, -21.1082718], [164.8284349, -21.0662996], [164.7904768, -21.054839], [164.7755831, -21.0633081], [164.7688106, -21.0849098], [164.7529318, -21.0788458], [164.757637100000011, -21.0597639], [164.7450355, -21.0496065], [164.7231668, -21.0637544], [164.6932373, -21.0395856], [164.6897497, -21.0017249], [164.7094894, -21.0040772], [164.7067892, -20.9825698], [164.6556483, -20.9841485], [164.6723464, -20.9342235], [164.6216822, -20.9163504], [164.5890382, -20.9273479], [164.569130300000012, -20.892148], [164.552801, -20.8970918], [164.5250124, -20.8921604], [164.5089198, -20.8691964], [164.48077090000001, -20.8485122], [164.4612292, -20.8478483], [164.457550700000013, -20.8304143], [164.431530900000013, -20.8131703], [164.415827799999988, -20.7823801], [164.3967001, -20.7723993], [164.4146743, -20.7516622], [164.4144246, -20.7186444], [164.3654563, -20.6951757], [164.3670383, -20.6740024], [164.350853199999989, -20.6725751], [164.3186751, -20.6313504], [164.316912300000013, -20.6091326], [164.3026815, -20.5838749], [164.2868978, -20.573296], [164.258135900000013, -20.5670717], [164.2370309, -20.5521269], [164.2364883, -20.54037], [164.213324699999987, -20.5244707], [164.2073595, -20.5111655], [164.1808225, -20.487898], [164.1705302, -20.4463535], [164.1563295, -20.4202766], [164.1257023, -20.4018423], [164.126215, -20.3836898], [164.1652777, -20.3964022], [164.184540199999986, -20.371021], [164.1721126, -20.3291925], [164.144252200000011, -20.2998123], [164.0730293, -20.2786775], [164.040154199999989, -20.3010513], [164.037128599999988, -20.2826233], [164.000372, -20.2479113], [164.0311723, -20.2282906], [164.063750199999987, -20.2339348], [164.0562004, -20.1925412], [164.0700522, -20.1846888], [164.057666500000011, -20.144823], [164.025324399999988, -20.129319], [164.028674099999989, -20.1153797], [164.0023314, -20.0845794], [164.0320476, -20.0789665], [164.049701199999987, -20.1025979], [164.063233, -20.1030358], [164.095028899999988, -20.1575225], [164.131015600000012, -20.1754754], [164.1487497, -20.2080064], [164.1804818, -20.2431799], [164.1916698, -20.2429742], [164.25087, -20.2695255], [164.251231, -20.283412], [164.3117672, -20.2784101], [164.3047134, -20.2553048], [164.310665, -20.2311869], [164.341089899999986, -20.239041], [164.3585182, -20.2363913], [164.3777026, -20.2571242], [164.4142171, -20.2614199], [164.4264464, -20.2738557], [164.4534861, -20.2797819], [164.4679377, -20.2917895], [164.497107199999988, -20.2988962], [164.5511526, -20.3354096], [164.5780385, -20.3630219], [164.5896354, -20.3983428], [164.6216206, -20.4180495], [164.648268300000012, -20.424928], [164.673311500000011, -20.452493], [164.699337899999989, -20.4679054], [164.7302652, -20.4752925], [164.760469, -20.4988843], [164.7754683, -20.5228282], [164.7943113, -20.5372731], [164.8016601, -20.5546776], [164.8172497, -20.5597038], [164.846866299999988, -20.6099504], [164.913438500000012, -20.6456126], [164.9393916, -20.6707201], [164.9789322, -20.6829271], [165.071405700000014, -20.7402132], [165.1201206, -20.7554108], [165.138711, -20.7530146], [165.2185845, -20.7654066], [165.243102, -20.7739308], [165.2633491, -20.8063676], [165.256842299999988, -20.8520489], [165.263199500000013, -20.8666957], [165.318514, -20.9267952], [165.336206, -20.9372319], [165.3739286, -20.9346014], [165.4144796, -20.9467328], [165.4002152, -20.9883047], [165.4080054, -21.0606532], [165.4482855, -21.1007745], [165.480973400000011, -21.1112429], [165.4966915, -21.1341154], [165.538398300000011, -21.1308979], [165.58438670000001, -21.1701432], [165.6108006, -21.1829011], [165.618982, -21.2043706], [165.599361, -21.2072991], [165.6012426, -21.2246554], [165.6176906, -21.2545568], [165.635116399999987, -21.269473], [165.6738412, -21.2866116], [165.6922245, -21.2846957], [165.714745, -21.3037548], [165.7386833, -21.2959742], [165.7594709, -21.2991074], [165.800537600000013, -21.3526414], [165.8265101, -21.3549125], [165.8205643, -21.3841647], [165.843593, -21.3729787], [165.882383800000014, -21.3781866], [165.8960925, -21.3721919], [165.9156729, -21.4045285], [165.9448879, -21.4368086], [165.9487681, -21.4627918], [165.942394299999989, -21.4767314], [165.9744895, -21.4955495], [165.9945328, -21.4985721], [165.9868898, -21.4666907], [165.9679088, -21.4456888], [165.9542559, -21.4184746], [165.9763479, -21.4119104], [166.0101659, -21.4516182], [166.0540547, -21.4737475], [166.0631108, -21.508706], [166.1201537, -21.5150268], [166.131238200000013, -21.5303691], [166.1724601, -21.5657266], [166.197636, -21.5761643], [166.239127200000013, -21.6141175], [166.2552547, -21.6167898], [166.2834368, -21.6341864], [166.3237818, -21.6487405], [166.337548199999986, -21.6436948], [166.3566363, -21.6530654], [166.342011899999989, -21.6797008], [166.373842200000013, -21.7002827], [166.4126547, -21.7055667], [166.4696166, -21.7517904], [166.4710179, -21.7771215], [166.5079098, -21.8134674], [166.5521269, -21.8477036], [166.5668703, -21.8765245], [166.614352599999989, -21.9035347], [166.6169094, -21.9151026], [166.656589700000012, -21.9368962], [166.6709227, -21.922156], [166.719904500000013, -21.9578165], [166.699598, -21.9672943], [166.700039299999986, -21.9811897], [166.7267999, -21.9803953], [166.7545269, -21.9909119], [166.7769518, -22.0144997], [166.820931800000011, -22.0255789], [166.870447899999988, -22.0333864], [166.9180634, -22.0765448], [166.9389611, -22.0851001], [166.951059500000014, -22.1171774], [166.9373224, -22.1568916], [166.9506256, -22.1557372], [167.0046911, -22.2264511], [167.0222407, -22.2796877], [167.003763600000013, -22.3350078], [166.9788179, -22.3381411], [166.9714217, -22.3499672], [166.9253012, -22.3951537], [166.916312299999987, -22.3775531], [166.887621599999989, -22.3701345], [166.8912914, -22.3530692], [166.8739209, -22.320439], [166.8507793, -22.3336387], [166.8277271, -22.3353628], [166.8081272, -22.3727499], [166.7821971, -22.3907191], [166.74138210000001, -22.3825907], [166.73044920000001, -22.3635203], [166.7462286, -22.3487986], [166.7004025, -22.3341523], [166.6843088, -22.3103236], [166.650377099999986, -22.2945673], [166.6295754, -22.2741266], [166.6095981, -22.2906604], [166.5905768, -22.2924874], [166.5572577, -22.26074], [166.568576299999989, -22.2442831], [166.548844300000013, -22.2373424], [166.508354, -22.2333561], [166.4948262, -22.2262117]]], [[[166.018878199999989, -21.9823795], [166.069872800000013, -21.9952624], [166.04525670000001, -22.0222013], [166.0313265, -22.0268053], [166.018878199999989, -21.9823795]]], [[[165.9709598, -21.9650781], [166.0080466, -21.9736499], [165.9964577, -21.986527], [165.9709598, -21.9650781]]], [[[163.9453417, -20.0320548], [163.9613918, -20.0360124], [163.968887, -20.014811], [163.9931971, -20.0477844], [163.9903981, -20.0593565], [163.9665833, -20.0754421], [163.9519055, -20.069433], [163.9453417, -20.0320548]]], [[[163.7892176, -20.049853], [163.7943749, -20.0346956], [163.811586, -20.028632], [163.8278637, -20.0380107], [163.815320899999989, -20.0755226], [163.7892176, -20.049853]]], [[[163.6208738, -19.61835], [163.6333099, -19.6259124], [163.6742126, -19.6916236], [163.6731316, -19.7238031], [163.699254599999989, -19.7384147], [163.7039, -19.7693485], [163.673275499999988, -19.7722142], [163.653972399999986, -19.754946], [163.652624300000014, -19.7372975], [163.635045100000013, -19.7098698], [163.6306116, -19.6876914], [163.6450346, -19.6697758], [163.6393692, -19.6486182], [163.6208738, -19.61835]]]]}},
            {"id": "ZZ-01", "dpt_id": "ZZ", "numero": 1, "geometry": {}},
            {"id": "ZZ-02", "dpt_id": "ZZ", "numero": 2, "geometry": {}},
            {"id": "ZZ-03", "dpt_id": "ZZ", "numero": 3, "geometry": {}},
            {"id": "ZZ-04", "dpt_id": "ZZ", "numero": 4, "geometry": {}},
            {"id": "ZZ-05", "dpt_id": "ZZ", "numero": 5, "geometry": {}},
            {"id": "ZZ-06", "dpt_id": "ZZ", "numero": 6, "geometry": {}},
            {"id": "ZZ-07", "dpt_id": "ZZ", "numero": 7, "geometry": {}},
            {"id": "ZZ-08", "dpt_id": "ZZ", "numero": 8, "geometry": {}},
            {"id": "ZZ-09", "dpt_id": "ZZ", "numero": 9, "geometry": {}},
            {"id": "ZZ-10", "dpt_id": "ZZ", "numero": 10, "geometry": {}},
            {"id": "ZZ-11", "dpt_id": "ZZ", "numero": 11, "geometry": {}},
        ]
        for circo_dict in circos_manquantes:
            if not session.execute(select(Departement).filter_by(code_insee=circo_dict['dpt_id'])).scalar_one_or_none():
                print("Département non trouvé avec le code", circo_dict['dpt_id'])
                continue

            if circo := session.execute(select(Circonscription).filter_by(id=circo_dict['id'])).scalar_one_or_none():
                circo.departement_code = circo_dict['dpt_id']
                circo.numero = circo_dict['numero']
                circo.geometry = circo_dict['geometry']
            else:
                circo = Circonscription(id=circo_dict['id'], departement_code=circo_dict['dpt_id'],
                                        numero=circo_dict['numero'], geometry=circo_dict['geometry'])
                session.add(circo)

        session.commit()


def importer_communes(engine: Engine, verbose: bool = False) -> None:
    etag = requests.get(
        "https://public.opendatasoft.com/api/explore/v2.1/catalog/datasets"
        "/georef-france-commune-arrondissement-municipal?select=data_processed").json()['data_processed']
    file = get_file("https://public.opendatasoft.com/api/explore/v2.1/catalog/datasets"
                    "/georef-france-commune-arrondissement-municipal/exports/geojson?lang=fr&timezone=Europe%2FParis",
                    "georef-france-commune-arrondissement-municipal.geojson", etag)

    with file.open('r') as f:
        features = json.load(f)['features']

    with Session(engine) as session:
        for feature in tqdm(features, desc="Communes", disable=not verbose):
            commune_dict = feature['properties']
            code_commune = commune_dict['com_arm_code'][0]
            nom_commune = commune_dict['com_name'][0]

            if commune := session.execute(select(Commune).filter_by(code_insee=code_commune)).scalar_one_or_none():
                commune.libelle = nom_commune
                commune.departement_code = commune_dict['dep_code'][0]
                commune.geometry = feature['geometry']
            else:
                commune = Commune(code_insee=code_commune, libelle=nom_commune,
                                  departement_code=commune_dict['dep_code'][0], geometry=feature['geometry'])
                session.add(commune)

        session.commit()


def importer_bureaux_vote(engine: Engine, verbose: bool = False) -> None:
    file = get_file("https://files.data.gouv.fr/reu/contours-france-entiere-latest-v2.geojson",
                    "contours-france-entiere-latest-v2.geojson")

    with file.open('r') as f:
        features = json.load(f)['features']

    with Session(engine) as session:
        for feature in tqdm(features, desc="Bureaux de vote", disable=not verbose):
            bv_dict = feature['properties']
            code_commune = bv_dict['id_bv'].split('_')[0]
            code_bv = bv_dict['numeroBureauVote']
            dpt_code = bv_dict['codeDepartement']

            match dpt_code:
                case "ZA":
                    dpt_code = "971"
                case "ZB":
                    dpt_code = "972"
                case "ZC":
                    dpt_code = "973"
                case "ZD":
                    dpt_code = "974"
                case "ZS":
                    dpt_code = "975"
                case "ZM":
                    dpt_code = "976"

            numero_circo = int(bv_dict['codeCirconscription'][len(dpt_code):])
            code_circo = f"{dpt_code}-{numero_circo:02d}"
            bv_id = bv_dict['id_bv'].split()[0]
            bv_libelle = f"Bureau {code_bv}"

            if not session.execute(select(Commune).filter_by(code_insee=code_commune)).scalar_one_or_none():
                print("Commune non trouvée avec le code", code_commune, "et le nom", bv_dict['nomCommune'])
                continue

            if not session.execute(select(Circonscription).filter_by(id=code_circo)).scalar_one_or_none():
                session.add(Circonscription(id=code_circo, departement_code=dpt_code, numero=numero_circo))

            if bv := session.execute(select(BureauVote).filter_by(id=bv_id)).scalar_one_or_none():
                bv.commune_code = code_commune
                bv.code_bureau = code_bv
                bv.circo_code = code_circo
                bv.libelle = bv_libelle
                bv.geometry = feature['geometry']
            else:
                bv = BureauVote(id=bv_id, commune_code=code_commune, code_bureau=code_bv, circo_code=code_circo,
                                libelle=bv_libelle, adresse="", geometry=feature['geometry'])
                session.add(bv)

        session.commit()


def run(engine: Engine, verbose: bool = False) -> None:
    importer_regions(engine, verbose)
    importer_departements(engine, verbose)
    importer_circonscriptions(engine, verbose)
    importer_communes(engine, verbose)
    importer_bureaux_vote(engine, verbose)
